;    Copyright 2012 Kurtis Liggett
;    This file is part of Simple IP Config.
;
;    Simple IP Config is free software: you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation, either version 3 of the License, or
;    (at your option) any later version.
;
;    Simple IP Config is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with Simple IP Config.  If not, see <http://www.gnu.org/licenses/>.

;===================================================================================================
; Name            	: _AdapterMod
; Description      	: Activate or deactivate a network adapter
; Syntax            : _AdapterMod($oLanConnection[, $bEnable])
; Parameter(s)    	: $oLanConnection - The name of the Lan connection.
;                     $bEnable        - The state to set the NIC.
;										- 1 for activate : Default
;										- 0 for disable
;										- 2 to get current state
; Requirement(s)   	: WinXP or greater (Windows 2000 untested)
; Return value(s)   : 0 - Success
;					  1 - Could not find Network Connections folder
;					  2 - Could not find the selected Connection name
;					  3 - Enable adapter failed
;					  4 - Disable adapter failed
; Author            : SnappyDog
;                     http://sourceforge.net/p/simpleipconfig
; Note(s)          	: Much of this code was modified from works by the following:
;					  SvenP and Tlem on the Autoit forums
;					  http://www.autoitscript.com/forum/index.php?showtopic=12645&view=findpost&p=87000
; ====================================================================================================

;===================================================================================================
; Name            	: _GetAdapters
; Description      	: Activate or deactivate a network adapter
; Syntax            : _GetAdapters()
; Requirement(s)   	: WinXP or greater (Windows 2000 untested)
; Return value(s)   : On Success - Return array containing connection names
;                     On Failure - Return 1
; Author            : SnappyDog
;                     http://sourceforge.net/p/simpleipconfig
; ====================================================================================================
_AdapterMod("Local Area Connection", 1)

Func _AdapterMod($oLanConnection, $bEnable = 1)
	Local $strEnableVerb, $strDisableVerb, $ShellApp, $oNetConnections, $oEnableVerb, $oDisableVerb
	Local $begin, $dif, $Res, $temp
; Langage selection.
    Select
		; English (United States)
        Case StringInStr("0409,0809,0c09,1009,1409,1809,1c09,2009,2409,2809,2c09,3009,3409", @OSLang)
            $strEnableVerb = "En&able"
            $strDisableVerb = "Disa&ble"

        ; Franais (France)
        Case StringInStr("040c,080c,0c0c,100c,140c,180c", @OSLang)
            $strEnableVerb = "&Activer"
            $strDisableVerb = "&Dsactiver"
    EndSelect

; Create virtual folder for Network Connections
    Const $ssfCONTROLS = 49
    $ShellApp = ObjCreate("Shell.Application")				; create shell object
    $oNetConnections = $ShellApp.Namespace($ssfCONTROLS)	; get Network Connections Namespace object

; If no 'Network connections' folder then return error.
    If Not IsObj($oNetConnections) Then
;~         MsgBox( 48, "Error", "Network Connections not found.")
        Return 1
    EndIf

; Find the collection of the network connection name.
    For $FolderItem In $oNetConnections.Items
        If StringLower($FolderItem.Name) = StringLower($oLanConnection) Then
            $oLanConnection = $FolderItem
            ExitLoop
        EndIf
    Next

; If no network connection name then return error.
    If Not IsObj($oLanConnection) Then
;~         MsgBox( 48, "Error", "Could not find " & $oLanConnection)
        Return 2
    EndIf

    $oEnableVerb  = ""
    $oDisableVerb = ""

; Find the state of the network connection.
    For $Verb In $oLanConnection.Verbs
        If $Verb.Name = $strEnableVerb Then
            $oEnableVerb = $Verb
        EndIf
        If $Verb.Name = $strDisableVerb Then
            $oDisableVerb = $Verb
        EndIf
        If $Verb.Name = "p$roperties" Then
            $temp = $Verb
        EndIf
;~         MsgBox(0,"",$Verb.Name)
    Next

If IsObj($temp) Then
	$temp = $temp.DoIt
	$ShellApp.explore($temp)
EndIf

; Enable NIC
    If $bEnable = 1 Then
        If IsObj($oEnableVerb) Then $oEnableVerb.DoIt
    EndIf

; Disable NIC
    If $bEnable = 0 Then
        If IsObj($oDisableVerb) Then $oDisableVerb.DoIt
	EndIf

; Get State
    If $bEnable = 2 Then
		$Res = _GetNicState($oLanConnection, $strEnableVerb, $strDisableVerb)
		If $Res = 1 Then
			Return "Enabled"
		Else
			Return "Disabled"
		EndIf
    EndIf

    $begin = TimerInit()
    While 1
        $dif = Int(TimerDiff($begin) / 1000)
        If $dif > 10 Then
			MsgBox( 0, "", "Timeout Error:" & @CRLF & "The command was issued, but the adapter took too long to check the state.")
			ExitLoop	; 10 second maximum waiting time
		EndIf
		; Control the state of the NIC to exit before the end of waiting time.
        If $bEnable = 1 And _GetNicState($oLanConnection, $strEnableVerb, $strDisableVerb) = 1 Then ExitLoop
        If $bEnable = 0 And _GetNicState($oLanConnection, $strEnableVerb, $strDisableVerb) = 0 Then ExitLoop
        Sleep(100)
    WEnd

; Set the return value of the function.
    $Res = _GetNicState($oLanConnection, $strEnableVerb, $strDisableVerb)
    If $bEnable = 1 And $Res = 0 Then
        Return 3
    ElseIf $bEnable = 0 And $Res = 1 Then
        Return 4
    Else
        Return 0
    EndIf
EndFunc

; Function that give the state of the lan connection (1 = Active  0 = Not Active).
Func _GetNicState($oLanConnection, $strEnableVerb="En&able", $strDisableVerb="Disa&ble")
	Local $Verb
    For $Verb In $oLanConnection.Verbs
        If $Verb.Name = $strEnableVerb Then
            Return 0
        Else
            Return 1
        EndIf
    Next
EndFunc

; Function to get a list of all network adapters
Func _GetAdapters()
	Local $myadapters, $ShellApp, $oNetConnections, $Bound, $FolderItem
	$myadapters = 0

; Create virtual folder for Network Connections
    Const $ssfCONTROLS = 49
    $ShellApp = ObjCreate("Shell.Application")				; create shell object
    $oNetConnections = $ShellApp.Namespace($ssfCONTROLS)	; get Network Connections Namespace object

; If no 'Network connections' folder then return error.
    If Not IsObj($oNetConnections) Then
;~         MsgBox( 48, "Error", "Network Connections not found.")
        Return 1
    EndIf

; Find the network adapters
    For $FolderItem In $oNetConnections.Items
		If IsArray($myadapters) = 1 Then			; check to see if array
			$Bound = UBound($myadapters)
			ReDim $myadapters[$Bound+1]				; expand the array
			$myadapters[$Bound] = $FolderItem.name
		Else										; create array
			Dim $myadapters[1]
			$myadapters[0] = $FolderItem.name
		EndIf
    Next

	Return $myadapters
EndFunc