#Region - Comments
;    Copyright 2012 Kurtis Liggett
;    Simple IP Config is free software: you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation, either version 3 of the License, or
;    (at your option) any later version.
;    Simple IP Config is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;    You should have received a copy of the GNU General Public License
;    along with Simple IP Config.  If not, see <http://www.gnu.org/licenses/>.

;    Simple IP Config 2.3
;    2012/04/08
;    Author: Kurtis Liggett

;~ Simple IP Config is a program written in AutoIt
;~ for Windows to easily change various network settings
;~ including IP Address, Subnet Mask, Gateway, and DNS Server
;~ in a format similar to the built-in Windows configuration.

;~ Acknowledgements:
;~ Phillip123Adams for the GetDPI.au3 script

#EndRegion ; comments

#Region - Error Codes
; Error messages for the program
; Error Codes:
;	0		-	No Errors
;	1-5		-	Input Error
;	6-11	-	Problem with WMI
;   30		-	Could not retrieve adapters
;   31-49   -   Array Errors
;	50		-	No profiles.ini after refresh
;	51-58	-	file read/write error
;	99		-   Could not open WMI COM object : Fatal
;	101-104	-	Adapter enable/disable error
; Status Messages:
;	- DHCP Server not found or not ready
;	- Adapter not connected
#EndRegion


#Region - Includes, Opts, Etc...
#requireadmin
#include <GUIConstantsEx.au3>
#include <GUIConstants.au3>
#include <EditConstants.au3>
#include <WindowsConstants.au3>
#include <Constants.au3>
#include <StaticConstants.au3>
#Include <Misc.au3>
#include <ButtonConstants.au3>
#include <ComboConstants.au3>
#include <GUIComboBox.au3>
#include <GuiListView.au3>
#include <WinAPI.au3>
#include <Math.au3>
#include <Array.au3>
#include <GuiMenu.au3>

#include <AdapterMod.au3>
#include <GetDPIUDF\GetDPI.au3>
#include <IconsUDF\Icons.au3>
Opt("GUIOnEventMode",1)
Opt("TrayAutoPause",0)
Opt("TrayOnEventMode",1)
Opt("TrayMenuMode",1)
Opt("MustDeclareVars", 1)
Opt("GUIResizeMode", $GUI_DOCKALL)
TraySetClick(16)
#EndRegion

#Region - Globals

; GUI settings
Global $winname = 'Simple IP Config'
Global $windate = '2012/04/08'
Global $winversion = "2.3"
Global $pFileLoc = "profiles.ini"
Global $GUI, $guiwidth, $guiheight, $tbheight, $optionchild, $filechild, $AboutChild, $menuheight, $captionborder
; DPI variables
Global $dr
; Buttons
Global $bt_tray, $bt_clear, $bt_apply, $bt_save, $bt_saveas, $bt_delete, $bt_refresh, $bt_adv, $bt_get
; Labels
Global $ip_lab, $sm_lab, $gw_lab, $dns_lab, $altdns_lab, $dhcp_lab, $AdapterState_lab				; current settings labels
Global $ipset_lab, $smset_lab, $gwset_lab, $dnsset_lab, $altdnsset_lab, $dhcpset_lab, $AdapterStateSet_lab	; current settings labels
Global $lb_ip, $lb_sm, $lb_gw, $lb_dnsp, $lb_dnsa				; change settings labels
Global $status_lab, $statusset_lab, $MoreLess_lab				; status message label
; Input boxes
Global $newip, $newsm, $newgw, $dnsa, $dnsp
; Radio Selection
Global $rd_ipauto, $rd_ipmanual, $rd_dnsauto, $rd_dnsmanual
; ComboBox
Global $connection, $combodummy, $inputdummy
; inputbox values
Global $ip, $sm, $gw, $dns1, $dns2, $adapter_sel				; reading input values
Global $lastip = 0
; accelerators - Keyboard shortcuts
Global $accels
; Checkboxes
Global $ck_disable, $ck_disablefw, $ck_advonstart, $ck_autorefresh, $ck_TypDNS, $ck_TypGateway
; Profile variables
Global $plistview
Global $pname = "Default"
Global $autoref = 0
Global $autogw = 0
Global $autodns = 0
Global $AdvancedMode = 0
; Graphics
Global $statusbox, $statusbox2
; Global Fonts
Global Const $font = 'Tahoma'
Global Const $fontsize = 10
Global Const $fontcolor = 0x000000
Global Const $fontboldsize = 11
Global Const $bkcolor = 0xf0f0f0
Global $MyGlobalFontName = "Arial"
Global $MyGlobalFontSize = 10
Global $MYGlobalFontSizeLarge = 11
Global $MyGlobalFontColor = 0x000000
Global $MyGlobalFontBKColor = $GUI_BKCOLOR_TRANSPARENT
; tray items
Global $restoreitem, $aboutitem, $exititem
; Menu items
Global $advitem
; Error handling
Global $oErrors = ObjEvent("AutoIt.Error", "Error_Handle")
Global $ErrorState = 0
; WMI
Global $objWMI
Global Const $wbemFlagReturnImmediately = 0x10
Global Const $wbemFlagForwardOnly = 0x20
; advanced mode label timer bit
Global $advTimerReset = 0

#EndRegion

#Region - Wrapper Options

; autoit wrapper options
#AutoIt3Wrapper_UseX64=N
#AutoIt3Wrapper_Icon=sic.ico
#AutoIt3Wrapper_Res_Icon_Add=sicBIG.ico
#AutoIt3Wrapper_OutFile=Simple IP Config 2.3.exe

#EndRegion


_Main()
#Region - Main Program Loop
Func _main()
	Local $a1, $iDPI, $iDPIRat, $timerhold=0, $labtimer, $labtimerdiff
	_WMIstart()			; start WMI First
	; get current DPI
	$a1 = _GetDPI()
	$iDPI = $a1[1]
	$iDPIRat = $a1[2]
	$dr = $iDPIRat
	$a1 = 0 ; delete array to save memory
	_guimaker()		; Create GUI and get adapter information
	_currentStats()	; Get current network settings
	If $ErrorState = 0 Then
		GuiCtrlSetData( $statusset_lab, "Ready" )
	EndIf

	While 1
		If (StringInStr( GUICtrlRead( $statusset_lab ), "Advanced") <> 0 AND $timerhold = 0) Or (StringInStr( GUICtrlRead( $statusset_lab ), "Advanced") <> 0 AND $advTimerReset = 1) Then
			$labtimer = TimerInit()
			$timerhold = 1
			$advTimerReset = 0
		EndIf
		If $timerhold = 1 Then
			$labtimerdiff = TimerDiff($labtimer)
			If $labtimerdiff > 1000 Then
				GuiCtrlSetData( $statusset_lab, "Ready" )
				$timerhold = 0
			EndIf
		EndIf
		Sleep(100)
	WEnd
EndFunc ; main()

#EndRegion

#Region - Make the GUI
Func _guimaker()
	Local $filemenu, $saveitem, $saveasitem, $deleteitem, $separator1, $exititem, $renameitem, $loaditem
	Local $viewmenu, $refreshitem, $send2trayitem, $toolsmenu, $clearitem, $optionsitem, $helpmenu, $helpitem, $infoitem, $getitem
	Local $restoreitem, $aboutitem, $exititem
	Local $enterdummy, $deletedummy, $optionsdummy, $traydummy, $renamedummy, $loaddummy
	Local $advstate, $Lclientsize, $LCaptionBorder, $pic

	; set GUI width, height based on current DPI
	$guiwidth = 570*$dr
	$guiheight = 401*$dr

	;~ Create GUI
	$GUI = GUICreate( $winname & " " & $winversion, $guiwidth, $guiheight, @DesktopWidth/2-$guiwidth/2, @DesktopHeight/2-$guiheight/2, -1, BITOR($WS_EX_COMPOSITED,$WS_CLIPCHILDREN) )
;~ 	GUISetBkColor( $bkcolor)
	GUISetOnEvent( $GUI_EVENT_CLOSE, "_closer")
	GUISetOnEvent( $GUI_EVENT_MINIMIZE, "_minimize")
	GUISetOnEvent( $GUI_EVENT_RESTORE, "_maximize")

	; set up main menu
	$filemenu = GUICtrlCreateMenu("&File")
	$saveitem = GUICtrlCreateMenuItem("Save" & @TAB & "Ctrl+s", $filemenu)
	GUICtrlSetOnEvent( -1, "_save" )
	$saveasitem = GUICtrlCreateMenuItem("Save As..." & @TAB & "Ctrl+Shift+s", $filemenu)
	GUICtrlSetOnEvent( -1, "_saveas" )
	$renameitem = GUICtrlCreateMenuItem("Rename Profile" & @TAB & "F2", $filemenu)
	GUICtrlSetOnEvent( -1, "_Rename" )
	$deleteitem = GUICtrlCreateMenuItem("Delete Profile" & @TAB & "Del", $filemenu)
	GUICtrlSetOnEvent( -1, "_delete" )
	$loaditem = GUICtrlCreateMenuItem("Load File" & @TAB & "Ctrl+l", $filemenu)
	GUICtrlSetOnEvent( -1, "_ConfigFileFind" )
	$separator1 = GUICtrlCreateMenuItem("", $filemenu) 	; create a separator line
	$exititem = GUICtrlCreateMenuItem("Exit" & @TAB & "Esc", $filemenu)
	GUICtrlSetOnEvent( -1, "_closer" )
	$viewmenu = GUICtrlCreateMenu("View")
	$refreshitem = GUICtrlCreateMenuItem("Refresh" & @TAB & "Ctrl+r", $viewmenu)
	GUICtrlSetOnEvent( -1, "_refresh" )
	$advitem = GUICtrlCreateMenuItem("Advanced Mode" & @TAB & "Ctrl+m", $viewmenu)
	GUICtrlSetOnEvent( -1, "_showADV" )
	$send2trayitem = GUICtrlCreateMenuItem("Send to Tray" & @TAB & "Ctrl+t", $viewmenu)
	GUICtrlSetOnEvent( -1, "_send2tray" )
	$toolsmenu = GUICtrlCreateMenu("Tools")
	$optionsitem = GUICtrlCreateMenuItem("Options..." & @TAB & "Ctrl+o", $toolsmenu)
	GUICtrlSetOnEvent( -1, "_optionscreen" )
	$clearitem = GUICtrlCreateMenuItem("Clear Entries" & @TAB & "Ctrl+e", $toolsmenu)
	GUICtrlSetOnEvent( -1, "_clear" )
	$getitem = GUICtrlCreateMenuItem("Match Entries to Current Settings" & @TAB & "Ctrl+g", $toolsmenu)
	GUICtrlSetOnEvent( -1, "_SetCurrent" )
	$helpmenu = GUICtrlCreateMenu("Help")
	$helpitem = GUICtrlCreateMenuItem("Online Documentation" & @TAB & "F1", $helpmenu)
	GUICtrlSetOnEvent( -1, "_onlinehelp" )
	$infoitem = GUICtrlCreateMenuItem("About Simple IP Config", $helpmenu)
	GUICtrlSetOnEvent( -1, "_about" )

	$Lclientsize = WinGetClientSize( $GUI )
	$menuheight = $guiheight - $Lclientsize[1]
	$LCaptionBorder = WinGetPos( $GUI )
	$captionborder = $LCaptionBorder[3] - ($Lclientsize[1]+$menuheight)

	;~ Set up tray menu
	$restoreitem      = TrayCreateItem("Restore")
	TrayItemSetOnEvent(-1, "_maximize")
	$aboutitem      = TrayCreateItem("About")
	TrayItemSetOnEvent(-1, "_about")
	TrayCreateItem("")
	$exititem       = TrayCreateItem("Exit")
	TrayItemSetOnEvent(-1, "_closer")
	TraySetOnEvent($TRAY_EVENT_PRIMARYDOUBLE, "_maximize")

	_ReadOptions()
	_advancedcontrols()
	_MakeProfiles()
	_CurrentInfo()
	_ChangeInfo()
	_Footer()
	GUICtrlSetState( $plistview, $GUI_FOCUS)
	ControlListView( $winname & " " & $winversion, "", $plistview, "Select", 0 )
	_setprof()

	; trick to accept enter on input boxes
	$enterdummy = GUICtrlCreateDummy()
	GUICtrlSetOnEvent( -1, "_Enter")
	$renamedummy = GUICtrlCreateDummy()
	GUICtrlSetOnEvent( -1, "_Rename" )
	$deletedummy = GUICtrlCreateDummy()
	GUICtrlSetOnEvent( -1, "_deletekey" )
	$optionsdummy = GUICtrlCreateDummy()
	GUICtrlSetOnEvent( -1, "_optionscreen" )
	$traydummy = GUICtrlCreateDummy()
	GUICtrlSetOnEvent( -1, "_send2tray" )
	$loaddummy = GUICtrlCreateDummy()
	GUICtrlSetOnEvent( -1, "_ConfigFileFind" )
	Dim $accels[13][2]=[["{ENTER}", $enterdummy], ["^t", $traydummy], ["^m", $bt_adv], ["^s", $bt_save], ["^+s", $bt_saveas], _
		["{F1}", $helpitem], ["^e", $bt_clear], ["{F2}", $renamedummy], ["{DEL}", $deletedummy], ["^r", $bt_refresh], _
		["^o", $optionsdummy], ["^l", $loaddummy], ["^g", $bt_get]]
	GUISetAccelerators($accels)
	$advstate = IniRead( $pFileLoc, "options", "AdvancedMode", "FALSE")
	If $advstate = "TRUE" Then
		_showADV()
	Else
		_hideADV()
	EndIf
	GUISetState(@SW_SHOW, $GUI)
	GUICtrlSetState( $newip, $GUI_FOCUS)
EndFunc ; guimaker()

; ----------------------------------------------------- ;
;	Make the profiles box and load in the list
; ----------------------------------------------------- ;
Func _MakeProfiles()
	Local $lvcontext, $lvcon_delete, $lvcon_rename, $listviewoutline, $LVHeaderBG, $listview_lab
	Local $LVWidth = 255*$dr, $LVHeight = 111*$dr, $HeaderHeight = 22*$dr
	Local $TotalLVHeight = $LVHeight+$HeaderHeight+1*$dr

	; Create the ListView header
	$LVHeaderBG = GUICtrlCreateGraphic( 0, 0, 0, 0)
	GUICtrlSetState( -1, $GUI_DISABLE)
	_DrawRect( -1, 0, 0, $LVWidth, $HeaderHeight, 1, 0xF0F0F0, 0xF0F0F0)
	_DrawLine( -1, 0, $HeaderHeight, $LVWidth, $HeaderHeight, 1, 0xa6a6a6)	; bottom line
	$listview_lab = GUICtrlCreateLabel( "User Profiles", 5*$dr, 4*$dr, 100*$dr, 20*$dr)
	_SetMyFont( -1, $MyGlobalFontSize, -1, -1, $MyGlobalFontName, -1, $MyGlobalFontColor, $MyGlobalFontBKColor)

	; Create the ListView
	$plistview = GUICtrlCreateListView( "Profiles", 0, $HeaderHeight+1*$dr, $LVWidth, $LVHeight, BitOR($GUI_SS_DEFAULT_LISTVIEW, $LVS_NOCOLUMNHEADER), $WS_EX_TRANSPARENT) ;$LVS_SORTDESCENDING optional
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor)
	_GUICtrlListView_SetColumnWidth($plistview, 0, $LVWidth-20*$dr)		; sets column width

	; draw the outline
	$listviewoutline = GUICtrlCreateGraphic ( 0, 0, 0, 0 )
	GUICtrlSetState( -1, $GUI_DISABLE)
	_DrawLine( -1, $LVWidth, 0, $LVWidth, $TotalLVHeight, 1, 0xa6a6a6)	; right line
	_DrawLine( -1, 0, $TotalLVHeight, $LVWidth+1*$dr, $TotalLVHeight, 1, 0xa6a6a6)	; bottom line

	; ListView Context Menu
	$lvcontext = GUICtrlCreateContextMenu($plistview)
	$lvcon_rename = GUICtrlCreateMenuItem("Rename", $lvcontext)
	GUICtrlSetOnEvent( -1, "_Rename")
	$lvcon_delete = GUICtrlCreateMenuItem("Delete", $lvcontext)
	GUICtrlSetOnEvent( -1, "_delete")

	; refresh button, delete button
	$bt_delete = GUICtrlCreateButton( "Delete", 3*$dr, 138*$dr, 50*$dr, 22*$dr)
	GUICtrlSetOnEvent( -1, "_delete")
	$bt_refresh = GUICtrlCreateButton( "Refresh", 190*$dr, 138*$dr, 50*$dr, 22*$dr)
	GUICtrlSetOnEvent(-1, "_refresh")
	_refreshpnames()
EndFunc	; _MakeProfiles

;~ --------------------------------------------------- ~;
;~  Create box to display current network information
;~ --------------------------------------------------- ~;
Func _CurrentInfo()
	Local $listviewoutline, $infobox, $boxoutline
	Local $currinfo_lab
	Local $boxcolor = 0xFFFFFF, $boxoutline = 0xa6a6a6
	Local $boxwidth = 255*$dr, $boxheight = 170*$dr, $HeaderHeight = 26*$dr

	$infobox = GUICtrlCreateGraphic ( 0, $dr*173, 0, 0 )
	GUICtrlSetState( -1, $GUI_DISABLE)
	_DrawRect( -1, 0, 0, $boxwidth, $boxheight, 1, $boxcolor, $boxcolor)	;box background
	_DrawLine( -1, 0, 0, $boxwidth, 0, 1, $boxoutline)						;top
	_DrawLine( -1, 0, $HeaderHeight, $boxwidth, $HeaderHeight, 1, $boxoutline)						;middle
	_DrawLine( -1, $boxwidth, 0, $boxwidth, $boxheight, 1, $boxoutline)		;right
	_DrawLine( -1, 0, $boxheight, $boxwidth, $boxheight, 1, $boxoutline)	;bottom

	$currinfo_lab = GUICtrlCreateLabel( "Current Information", 7*$dr, 179*$dr, 150*$dr, 30*$dr)
	_SetMyFont( -1, $MYGlobalFontSizeLarge, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $MyGlobalFontBKColor)

	; make labels as uneditable inputs to allow selecting the text
	$ip_lab = GUICtrlCreateInput("IP Address:", 7*$dr, 206*$dr, 120*$dr, 20*$dr, $ES_READONLY, $WS_EX_TRANSPARENT)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $boxcolor)
	$ipset_lab = GUICtrlCreateInput("", 144*$dr, 206*$dr, 104*$dr, 20*$dr, $ES_READONLY, $WS_EX_TRANSPARENT)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $boxcolor)
	$sm_lab = GUICtrlCreateInput( "Subnet Mask:", 7*$dr, 225*$dr, 130*$dr, 20*$dr, $ES_READONLY, $WS_EX_TRANSPARENT)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $boxcolor)
	$smset_lab = GUICtrlCreateInput("", 144*$dr, 225*$dr, 104*$dr, 20*$dr, $ES_READONLY, $WS_EX_TRANSPARENT)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $boxcolor)
	$gw_lab = GUICtrlCreateInput( "Default Gateway:", 7*$dr, 244*$dr, 130*$dr, 20*$dr, $ES_READONLY, $WS_EX_TRANSPARENT)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $boxcolor)
	$gwset_lab = GUICtrlCreateInput("", 144*$dr, 244*$dr, 104*$dr, 20*$dr, $ES_READONLY, $WS_EX_TRANSPARENT)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $boxcolor)
	$dns_lab = GUICtrlCreateInput( "Preferred DNS Server:", 7*$dr, 263*$dr, 130*$dr, 20*$dr, $ES_READONLY, $WS_EX_TRANSPARENT)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $boxcolor)
	$dnsset_lab = GUICtrlCreateInput("", 144*$dr, 263*$dr, 104*$dr, 20*$dr, $ES_READONLY, $WS_EX_TRANSPARENT)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $boxcolor)
	$altdns_lab = GUICtrlCreateInput( "Alternate DNS Server:", 7*$dr, 282*$dr, 130*$dr, 20*$dr, $ES_READONLY, $WS_EX_TRANSPARENT)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $boxcolor)
	$altdnsset_lab = GUICtrlCreateInput("", 144*$dr, 282*$dr, 104*$dr, 20*$dr, $ES_READONLY, $WS_EX_TRANSPARENT)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $boxcolor)
	$dhcp_lab = GUICtrlCreateInput( "DHCP Server:", 7*$dr, 301*$dr, 130*$dr, 20*$dr, $ES_READONLY, $WS_EX_TRANSPARENT)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $boxcolor)
	$dhcpset_lab = GUICtrlCreateInput("", 144*$dr, 301*$dr, 104*$dr, 20*$dr, $ES_READONLY, $WS_EX_TRANSPARENT)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $boxcolor)
	$AdapterState_lab = GUICtrlCreateInput( "Adapter State:", 7*$dr, 320*$dr, 130*$dr, 20*$dr, $ES_READONLY, $WS_EX_TRANSPARENT)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $boxcolor)
	$AdapterStateSet_lab = GUICtrlCreateInput("", 144*$dr, 320*$dr, 104*$dr, 20*$dr, $ES_READONLY, $WS_EX_TRANSPARENT)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $boxcolor)
EndFunc	; _CurrentInfo()
Func _ChangeInfo()
	Local $LeftAlign = 272
	Local $changealign = $LeftAlign+10
	Local $changeradios = $LeftAlign+10
	Local $changeinputs = $LeftAlign+155
	Local $myadapters
	Local $GFIPBox, $GFDNSBox, $box2

	; adapter selection
	$connection = GUICtrlCreateCombo(	"", $LeftAlign*$dr-1, 5*$dr, 285*$dr, 30*$dr, $CBS_DROPDOWNLIST)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor)
	$myadapters = _GetAdapters()	; populate combobox with adapter names
	If NOT IsArray( $myadapters ) Then
		MsgBox( 16, "Fatal Error", "Error Code 30" & @CR & _
					"There was a problem retreiving your adapters. Please report this to the author." )
		Exit
	Else
		_ArraySort($myadapters, 0)	; connections sort ascending
		For $i=0 to UBound($myadapters)-1
			GUICtrlSetData( $connection, $myadapters[$i], $myadapters[0])
		Next
		GUICtrlSetFont(-1, $fontsize, 400, Default, $font, 5)
		GUICtrlSetColor( -1, $fontcolor )
	EndIf
	; Create a dummy control to run a function on combobox selection
	$combodummy = GUICtrlCreateDummy()
	GUICtrlSetOnEvent(-1, "_refreshalt")
	GUIRegisterMsg($WM_COMMAND, "_WM_COMMAND")

	; IP address settings
	GUIStartGroup()
	$rd_ipauto = GUICtrlCreateRadio( "Obtain IP address automatically", $changeradios*$dr, 35*$dr, 210*$dr, 20*$dr)
	GUICtrlSetOnEvent( -1, "_radios")
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor)
	$rd_ipmanual = GUICtrlCreateRadio( "Use the following IP address:", $changeradios*$dr, 55*$dr, 185*$dr, 20*$dr)
	GUICtrlSetOnEvent( -1, "_radios")
	GUICtrlSetState( -1, $GUI_CHECKED)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor)
	$lb_ip = GUICtrlCreateLabel( "IP Address:", $changealign*$dr, 85*$dr, 100*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $MyGlobalFontBKColor)
	$newip = GUICtrlCreateInput( "---.---.---.---", $changeinputs*$dr, 83*$dr, 112*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor)
	$lb_sm = GUICtrlCreateLabel( "Subnet Mask:", $changealign*$dr, 107*$dr, 100*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $MyGlobalFontBKColor)
	$newsm = GUICtrlCreateInput( "---.---.---.---", $changeinputs*$dr, 105*$dr, 112*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor)
	$lb_gw = GUICtrlCreateLabel( "Gateway:", $changealign*$dr, 129*$dr, 100*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $MyGlobalFontBKColor)
	$newgw = GUICtrlCreateInput( "---.---.---.---", $changeinputs*$dr, 127*$dr, 112*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor)

	; inputbox dummy
	$inputdummy = GUICtrlCreateDummy( )
	GUICtrlSetOnEvent( -1, "_enablesave")

	; dns server settings
	GUIStartGroup()
	$rd_dnsauto = GUICtrlCreateRadio( "Obtain DNS server automatically", $changeradios*$dr, 172*$dr, 210*$dr, 20*$dr)
	GUICtrlSetOnEvent( -1, "_radios")
	GUICtrlSetState( $rd_dnsauto,$GUI_DISABLE )
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor)
	$rd_dnsmanual = GUICtrlCreateRadio( "Use the following DNS addresses:", $changeradios*$dr, 192*$dr, 215*$dr, 20*$dr)
	GUICtrlSetOnEvent( -1, "_radios")
	GUICtrlSetState( -1, $GUI_CHECKED)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor)
	$lb_dnsp = GUICtrlCreateLabel( "Preferred DNS Server:", $changealign*$dr, 222*$dr, 130*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $MyGlobalFontBKColor)
	$dnsp = GUICtrlCreateInput( "---.---.---.---", $changeinputs*$dr, 220*$dr, 112*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor)
	$lb_dnsa = GUICtrlCreateLabel( "Alternate DNS Server:", $changealign*$dr, 244*$dr, 130*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $MyGlobalFontBKColor)
	$dnsa = GUICtrlCreateInput( "---.---.---.---", $changeinputs*$dr, 242*$dr, 112*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor)

	; draw the box outlines for ip address
	$GFIPBox = GUICtrlCreateGraphic( ($LeftAlign-1)*$dr, 65*$dr, 285*$dr, 96*$dr )
	_DrawLine( -1, 1, 0, 9*$dr, 0, 1, 0xa6a6a6)						; top
	_DrawLine( -1, 190*$dr, 0, 285*$dr-1, 0, 1, 0xa6a6a6)
	_DrawLine( -1, 0, 1, 0, 96*$dr-1, 1, 0xa6a6a6)					; left
	_DrawLine( -1, 285*$dr-1, 1, 285*$dr-1, 96*$dr-1, 1, 0xa6a6a6)	; right
	_DrawLine( -1, 1, 96*$dr-1, 285*$dr-1, 96*$dr-1, 1, 0xa6a6a6)	; bottom
	GUICtrlSetGraphic(-1, $GUI_GR_PIXEL, 1, 1)						; top left corner
	GUICtrlSetGraphic(-1, $GUI_GR_PIXEL, 1, 96*$dr-2)				; bottom left corner
	GUICtrlSetGraphic(-1, $GUI_GR_PIXEL, 285*$dr-2, 1)				; top right corner
	GUICtrlSetGraphic(-1, $GUI_GR_PIXEL, 285*$dr-2, 96*$dr-2)		; bottom right corner


	; draw the box outlines for dns address
	$GFDNSBox = GUICtrlCreateGraphic( ($LeftAlign-1)*$dr, 202*$dr, 285*$dr, 74*$dr )
	_DrawLine( -1, 1, 0, 9*$dr, 0, 1, 0xa6a6a6)						; top
	_DrawLine( -1, 220*$dr, 0, 285*$dr-1, 0, 1, 0xa6a6a6)
	_DrawLine( -1, 0, 1, 0, 74*$dr-1, 1, 0xa6a6a6)					; left
	_DrawLine( -1, 285*$dr-1, 1, 285*$dr-1, 74*$dr-1, 1, 0xa6a6a6)	; right
	_DrawLine( -1, 1, 74*$dr-1, 285*$dr-1, 74*$dr-1, 1, 0xa6a6a6)	; bottom
	GUICtrlSetGraphic(-1, $GUI_GR_PIXEL, 1, 1)						; top left corner
	GUICtrlSetGraphic(-1, $GUI_GR_PIXEL, 1, 74*$dr-2)				; bottom left corner
	GUICtrlSetGraphic(-1, $GUI_GR_PIXEL, 285*$dr-2, 1)				; top right corner
	GUICtrlSetGraphic(-1, $GUI_GR_PIXEL, 285*$dr-2, 74*$dr-2)		; bottom right corner

	; bottom controls
	$bt_save = GUICtrlCreateButton( "Save", $LeftAlign*$dr, 285*$dr, 50*$dr, 22*$dr)
	GUICtrlSetOnEvent(-1, "_save")
	GUICtrlSetState($bt_save, $GUI_DISABLE)
	$bt_saveas = GUICtrlCreateButton( "Save As", $LeftAlign*$dr+55*$dr, 285*$dr, 50*$dr, 22*$dr)
	GUICtrlSetOnEvent(-1, "_saveas")
	$bt_clear = GUICtrlCreateButton( "Clear", $guiwidth-20*$dr-105*$dr, 285*$dr, 50*$dr, 22*$dr)
	GUICtrlSetOnEvent(-1, "_clear")
	$bt_apply = GUICtrlCreateButton( "Apply", $guiwidth-20*$dr-50*$dr, 285*$dr, 50*$dr, 22*$dr)
	GUICtrlSetOnEvent(-1, "_apply")
	$bt_get = GUICtrlCreateButton( "Get", $LeftAlign*$dr, 315*$dr, 50*$dr, 22*$dr)
	GUICtrlSetOnEvent(-1, "_setcurrent")
EndFunc ; _ChangeInfo()
Func _Footer()
	; make the box for the status label at bottom
	$statusbox = GUICtrlCreateGraphic ( 0, 357*$dr, 0, 0 )		;upper line
	GUICtrlSetState( -1, $GUI_DISABLE)
	_DrawLine( -1, 0, 0, $guiwidth, 0, 1, 0xE0E0E0)
	_DrawLine( -1, 0, 1, $guiwidth, 1, 1, 0xa6a6a6)
	_DrawLine( -1, 0, 2, $guiwidth, 2, 1, 0xFFFFFF)

	$statusbox2 = GUICtrlCreateGraphic ( 0, 404*$dr, 0, 0 )		;lower line
	GUICtrlSetState( -1, $GUI_DISABLE)
	_DrawLine( -1, 0, 0, $guiwidth, 0, 1, 0xE0E0E0)
	_DrawLine( -1, 0, 1, $guiwidth, 1, 1, 0xa6a6a6)
	_DrawLine( -1, 0, 2, $guiwidth, 2, 1, 0xFFFFFF)

	$status_lab = GUICtrlCreateLabel( "Status:", 0, 0, 40*$dr, 20*$dr)	;will be moved later
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $MyGlobalFontBKColor)

	$statusset_lab = GUICtrlCreateLabel("", 0, 0, 250*$dr, 20*$dr)		;will be moved later
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $MyGlobalFontBKColor)
EndFunc ; _BottomMenu()

#EndRegion
#Region - Advanced GUI

;	create advanced controls
Func _advancedcontrols()
	$bt_adv = GUICtrlCreateButton( Chr(0x36), 0, 0, 18*$dr, 18*$dr)		;will be moved later
	GUICtrlSetOnEvent(-1, "_showADV")
	GUICtrlSetFont(-1, 14, 400, -1, "WebDings")

	$MoreLess_lab = GUICtrlCreateLabel( "More", 0, 0, 50*$dr, 20*$dr)	;will be moved later
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $MyGlobalFontBKColor)

	$ck_disable = GUICtrlCreateCheckbox( "Disable Adapter", 10*$dr, 362*$dr, 175*$dr, 20*$dr)
	GUICtrlSetOnEvent( $ck_disable, "_radios" )
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor)
	$ck_disablefw = GUICtrlCreateCheckbox( "Disable Windows Firewall", 10*$dr, 382*$dr, 175*$dr, 20*$dr)
	GUICtrlSetOnEvent( $ck_disablefw, "_radios" )
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor)
EndFunc

;	Advanced GUI settings
Func _showADV()
	Local $currentpos, $newguiheight, $ypos, $heightdif, $taskb, $deskheight, $x, $xhold, $xhold2, $SizeStep, $RemSteps, $heightadd
	Local $BorderSize, $ClientSize, $newclientheight
	$advTimerReset = 1

	$heightadd = 47*$dr		; how much to grow
	$newguiheight = $guiheight + $captionborder + $heightadd			; original height + titlebar/border + how much to grow
	$newclientheight = $guiheight + $heightadd
	$taskb = @DesktopHeight - _WinAPI_GetSystemMetrics($SM_CYMAXIMIZED)	; sneaky way to get taskbar height
	$currentpos = WinGetPos( $winname & " " & $winversion )
	$ypos = $currentpos[1]
	$heightdif = $ypos + $newguiheight + $taskb*$dr + 30*$dr - @DesktopHeight

	; Reposition status labels and bottom button
	GUICtrlSetPos( $status_lab, 7*$dr, $newclientheight-38*$dr)
	GUICtrlSetPos( $statusset_lab, 52*$dr, $newclientheight-38*$dr)
	GUICtrlSetPos( $bt_adv, $guiwidth-25*$dr, $newclientheight-40*$dr)
	GUICtrlSetPos( $MoreLess_lab, $guiwidth-58*$dr, $newclientheight-38*$dr)
	GUICtrlSetOnEvent( $bt_adv, "_hideADV")
	GUICtrlSetOnEvent( $advitem, "_hideADV" )
	GUICtrlSetData( $advitem, "Basic Mode" & @TAB & "Ctrl+m")
	GUICtrlSetData( $bt_adv, Chr(0x35))
	GUICtrlSetData( $MoreLess_lab, "Less")

	; Show the hidden controls
	GUICtrlSetState( $ck_disable, $GUI_SHOW)
	GUICtrlSetState( $ck_disablefw, $GUI_SHOW)
	GUICtrlSetState( $statusbox2, $GUI_SHOW)

	GUICtrlSetData( $statusset_lab, "Advanced Mode Enabled")

	; grow the window
	If $heightdif > 0 Then
		WinMove( $winname & " " & $winversion, "", Default, $ypos-$heightdif)
		WinMove( $winname & " " & $winversion, "", Default, $ypos-$heightdif, Default, $newguiheight)
	Else
		WinMove( $winname & " " & $winversion, "", Default, Default, Default, $newguiheight)
	EndIf

	$AdvancedMode = 1
EndFunc

Func _hideADV()
	Local $newguiheight

	$advTimerReset = 1

	GUICtrlSetPos( $status_lab, 7*$dr, $guiheight-38*$dr)
	GUICtrlSetPos( $statusset_lab, 52*$dr, $guiheight-38*$dr)
	GUICtrlSetPos( $bt_adv, $guiwidth-25*$dr, $guiheight-40*$dr)
	GUICtrlSetPos( $MoreLess_lab, $guiwidth-58*$dr, $guiheight-38*$dr)
	GUICtrlSetOnEvent( $bt_adv, "_showADV")
	GUICtrlSetOnEvent( $advitem, "_showADV" )
	GUICtrlSetData( $advitem, "Advanced Mode" & @TAB & "Ctrl+m")
	GUICtrlSetData( $bt_adv, Chr(0x36))
	GUICtrlSetData( $MoreLess_lab, "More")

	; hide unused controls
	GUICtrlSetState( $ck_disable, $GUI_HIDE)
	GUICtrlSetState( $ck_disablefw, $GUI_HIDE)
	GUICtrlSetState( $statusbox2, $GUI_HIDE)

	$AdvancedMode = 0
	GUICtrlSetData( $statusset_lab, "Advanced Mode Disabled")

	; shrink the window
	$newguiheight = $guiheight + $captionborder		; original height + titlebar/border
	WinMove( $winname & " " & $winversion, "", Default, Default, Default, $newguiheight)
EndFunc

#EndRegion ;advanced gui

#Region - Options Screen
Func _optionscreen()
	Local $x=0
	Local $timerinit, $timerdiff, $bt_optCancel, $bt_optSave

	$optionchild = GUICreate( "Options", 240*$dr, 130*$dr, 165*$dr, 15*$dr, Default, $WS_EX_MDICHILD, $GUI)
	GUISetOnEvent( $GUI_EVENT_CLOSE, "_closerchild")
	$bt_optSave = GUICtrlCreateButton( "Save", 63*$dr, 98*$dr, 50*$dr, 22*$dr)
	GUICtrlSetOnEvent( $bt_optSave, "_SetOptions")
	$bt_optCancel = GUICtrlCreateButton( "Cancel", 123*$dr, 98*$dr, 50*$dr, 22*$dr)
	GUICtrlSetOnEvent( $bt_optCancel, "_closerchild")

	$ck_autorefresh = GUICtrlCreateCheckbox( "Automatically refresh adapter information", 10*$dr, 10*$dr, 230*$dr, 20*$dr)
	$ck_advonstart = GUICtrlCreateCheckbox( "Enable advanced mode on startup", 10*$dr, 30*$dr, 230*$dr, 20*$dr)
	$ck_TypGateway = GUICtrlCreateCheckbox( "Use typical gateway address", 10*$dr, 50*$dr, 230*$dr, 20*$dr)
	$ck_TypDNS = GUICtrlCreateCheckbox( "Use typical DNS addresses", 10*$dr, 70*$dr, 230*$dr, 20*$dr)

	_ReadOptions(1)

	GUISetState(@SW_DISABLE, $GUI)
;~ 	DllCall("user32.dll", "int", "AnimateWindow", "hwnd", $optionchild, "int", 100, "long", 0x80000 )
; puts a weird border around the window...
	GUISetState(@SW_SHOW, $optionchild)
EndFunc

#EndRegion ; options screen

#Region - File not found handler
Func _FileHandler()
	Local $bt_FileCreate, $bt_FileFind, $bt_FileCancel, $lb_Message

	$filechild = GUICreate( "File Not Found", 200*$dr, 120*$dr, 165*$dr, 15*$dr, Default, $WS_EX_MDICHILD, $GUI)
	GUISetOnEvent( $GUI_EVENT_CLOSE, "_closerfilechild")
	$lb_Message = GUICtrlCreateLabel( "Configuration file not found." & @CRLF & "What would you like to do?", 20, 10, 195, 50)
	GUICtrlSetFont(-1, $fontsize, 400, Default, $font, 5)
	GUICtrlSetColor( -1, $fontcolor )

	$bt_FileCreate = GUICtrlCreateButton( "Create", 15*$dr, 80*$dr, 50*$dr, 22*$dr)
	GUICtrlSetOnEvent( -1, "_ConfigFileCreate")
	$bt_FileFind = GUICtrlCreateButton( "Find", 70*$dr, 80*$dr, 50*$dr, 22*$dr)
	GUICtrlSetOnEvent( -1, "_ConfigFileFind")
	$bt_FileCancel = GUICtrlCreateButton( "Cancel", 125*$dr, 80*$dr, 50*$dr, 22*$dr)
	GUICtrlSetOnEvent( -1, "_closerfilechild")

	GUISetState(@SW_DISABLE, $GUI)
	GUISetState(@SW_SHOW, $filechild)

EndFunc

Func _ConfigFileCreate()
	Local $pfile
	If WinExists( "File Not Found" ) Then
		_closerfilechild()
	EndIf
	$pfile = FileOpen( "profiles.ini", 1 )
	FileWrite($pfile, "[Options]" & @CRLF & _
	"AdvancedMode = False" & @CRLF & _
	"AutoRefresh = False" & @CRLF & _
	"AutoGateway = False" & @CRLF & _
	"AutoDNS = False" & @CRLF )
	FileClose( $pfile )
	_saveas()
EndFunc

Func _ConfigFileFind()
	Local $ret
	If WinExists( "File Not Found" ) Then
		_closerfilechild()
	EndIf
	$ret = FileOpenDialog( "Choose Configuration File", @ScriptDir, "INI files (*.ini)", -1, "profiles.ini", $GUI)
	If @error Then
		Return 1
	EndIf
	$pFileLoc = $ret
	_refreshpnames()
EndFunc

Func _closerfilechild()
	GUISetState(@SW_ENABLE, $GUI)
	GUIDelete( $filechild )
	GUISetState(@SW_SHOW, $GUI)
EndFunc

#EndRegion ; File not found handler

#Region - Get Info
Func _wmistart()
	$objWMI = ObjGet("winmgmts:\\localhost\root\CIMV2")
	If Not IsObj($objWMI) Then
		$ErrorState = 1
		_wmierror(99,0)
		Return 1
	Else
		Return 0
	EndIf
EndFunc

;~ call appropriate functions for information
Func _currentStats($forcerefresh=0)
	Local $stats, $ret
	Local $timer = TimerInit()

	If $autoref = 0 And $forcerefresh = 0 Then
		If $ErrorState = 0 Then
			GuiCtrlSetData( $statusset_lab, "Ready" )
		EndIf
		Return ;early
	EndIf
	GuiCtrlSetData( $statusset_lab, "Refreshing..." )
	$adapter_sel = GUICtrlRead( $connection )
	$stats = _getIPs($adapter_sel)
	; need to implement an error checking here
	If StringStripWS ( $stats[0], 8 ) = "" Then
		$ErrorState = 1 ; don't return
		GuiCtrlSetData( $statusset_lab, "Adapter not connected")
	ElseIf StringRegExp($stats[0], '169\.{1}\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}', 0) = 1 Then
		$ErrorState = 1	; don't return
		GuiCtrlSetData( $statusset_lab, "DHCP Server was not found or is not ready.")
	EndIf
	GuiCtrlSetData( $ipset_lab,		$stats[0] )
	GuiCtrlSetData( $smset_lab,		$stats[1] )
	GuiCtrlSetData( $gwset_lab,		$stats[2] )
	GuiCtrlSetData( $dnsset_lab, 	$stats[3] )
	GuiCtrlSetData( $altdnsset_lab, $stats[4] )
	GuiCtrlSetData( $dhcpset_lab, 	$stats[5] )
	GuiCtrlSetData( $AdapterStateSet_lab, 	$stats[6] )

	If $ErrorState = 0 Then
		GuiCtrlSetData( $statusset_lab, "Ready" )
	EndIf
EndFunc

;~ get current IP, SM, and GW
Func _getIPs($adap)
	Local $FIP_info[7] = [0]
	Local $dnsbound, $ret
	Local $colItems, $Adapter_caption, $DNSServer, $dhcpp
	$colItems = $objWMI.ExecQuery("SELECT caption, NetConnectionID FROM Win32_NetworkAdapter WHERE NetConnectionID=""" & $adap & """", "WQL", $wbemFlagReturnImmediately + $wbemFlagForwardOnly)
	for $objItem in $colItems
		$Adapter_caption = $objItem.caption
		ExitLoop
	Next
	$colItems = $objWMI.ExecQuery("SELECT caption, IPAddress FROM Win32_NetworkAdapterConfiguration WHERE caption=""" & $Adapter_caption & """", "WQL", $wbemFlagReturnImmediately + $wbemFlagForwardOnly)
	For $objItem In $colItems
		$FIP_info[0] = $objItem.IPAddress(0)
		ExitLoop
	Next
	If $FIP_info[0] = 0 Then
		$FIP_info[0] = ""
	EndIf
	$colItems = $objWMI.ExecQuery("SELECT caption, IPSubnet FROM Win32_NetworkAdapterConfiguration WHERE caption=""" & $Adapter_caption & """", "WQL", $wbemFlagReturnImmediately + $wbemFlagForwardOnly)
	For $objItem In $colItems
		$FIP_info[1] = $objItem.IPSubnet(0)
		ExitLoop
	Next
	$colItems = $objWMI.ExecQuery("SELECT caption, DefaultIPGateway FROM Win32_NetworkAdapterConfiguration WHERE caption=""" & $Adapter_caption & """", "WQL", $wbemFlagReturnImmediately + $wbemFlagForwardOnly)
	For $objItem In $colItems
		$FIP_info[2] = $objItem.DefaultIPGateway(0)
		ExitLoop
	Next
	$colItems = $objWMI.ExecQuery("SELECT caption, DNSServerSearchOrder FROM Win32_NetworkAdapterConfiguration WHERE caption=""" & $Adapter_caption & """", "WQL", $wbemFlagReturnImmediately + $wbemFlagForwardOnly)
	For $objItem In $colItems
		$dnsbound = UBound($objItem.DNSServerSearchOrder())
		$DNSServer = $objItem.DNSServerSearchOrder(0)
		If $dnsbound = 0 Then
			$FIP_info[3] = ""
			$FIP_info[4] = ""
		ElseIf $dnsbound = 1 Then
			$FIP_info[3] = $objItem.DNSServerSearchOrder(0)
			$FIP_info[4] = ""
		Else ; $dnsbound = 2
			$FIP_info[3] = $objItem.DNSServerSearchOrder(0)
			$FIP_info[4] = $objItem.DNSServerSearchOrder(1)
		EndIf
		ExitLoop
	Next
	$colItems = $objWMI.ExecQuery("SELECT caption, DHCPEnabled, DHCPServer FROM Win32_NetworkAdapterConfiguration WHERE caption=""" & $Adapter_caption & """", "WQL", $wbemFlagReturnImmediately + $wbemFlagForwardOnly)
	For $objItem In $colItems
		$dhcpp = $objItem.DHCPEnabled
		If $dhcpp <> 0 Then
			$FIP_info[5] = $objItem.DHCPServer
		Else
			$FIP_info[5] = "Static"
		EndIf
		ExitLoop
	Next
	; get adapter state
	$ret = _AdapterMod($adapter_sel, 2)
	If $ret = 1 Then
		$ErrorState = 1
		_AdapterModErrors(101)
		Return 1
	EndIf
	If $ret = 2 Then
		$ErrorState = 1
		_AdapterModErrors(102)
		Return 1
	EndIf
	If $ret = 3 Then
		$ErrorState = 1
		_AdapterModErrors(103)
		Return 1
	EndIf
	If $ret = 4 Then
		$ErrorState = 1
		_AdapterModErrors(104)
		Return 1
	EndIf
	$FIP_info[6] = $ret
	Return( $FIP_info )
EndFunc
#EndRegion ;getinfo

#Region - UserFunctions
Func _DrawLine($ControlID, $x1, $y1, $x2, $y2, $pensize=1, $color=0x000000)
	Local $LControlID
	If $ControlID = -1 Then
		$LControlID = _GUIGetLastCtrlID()
	Else
		$LControlID = $ControlID
	EndIf
	GUICtrlSetGraphic($LControlID, $GUI_GR_PENSIZE, $pensize)
	GUICtrlSetGraphic($LControlID, $GUI_GR_COLOR, $color)
	GUICtrlSetGraphic($LControlID, $GUI_GR_MOVE, $x1, $y1)
	GUICtrlSetGraphic($LControlID, $GUI_GR_LINE, $x2, $y2)
EndFunc

Func _DrawRect($ControlID, $x1, $y1, $width, $height, $pensize=1, $BorderColor=0x000000, $bgColor=-1)
	Local $LControlID
	If $ControlID = -1 Then
		$LControlID = _GUIGetLastCtrlID()
	Else
		$LControlID = $ControlID
	EndIf
	GUICtrlSetGraphic($LControlID, $GUI_GR_PENSIZE, $pensize)
	If $bgColor = -1 Then
		GUICtrlSetGraphic($LControlID, $GUI_GR_COLOR, $BorderColor)
	Else
		GUICtrlSetGraphic($LControlID, $GUI_GR_COLOR, $BorderColor, $bgColor)
	EndIf
	GUICtrlSetGraphic($LControlID, $GUI_GR_RECT, $x1, $y1, $width,  $height)
EndFunc

Func _SetMyFont($ControlID, $size, $weight=-1, $attribute=-1, $fontname=-1, $quality=5, $color=0x000000, $bkcolor=-1)
	Local $LControlID
	If $ControlID = -1 Then
		$LControlID = _GUIGetLastCtrlID()
	Else
		$LControlID = $ControlID
	EndIf
	GUICtrlSetFont( $LControlID, $size, $weight, $attribute, $fontname, $quality)
	GUICtrlSetColor( -1, $color )
	If $bkcolor <> -1 Then
		GUICtrlSetBkColor( -1, $bkcolor  )
	EndIf
EndFunc

Func _GUIGetLastCtrlID()
    Local $aRet = DllCall("user32.dll", "int", "GetDlgCtrlID", "hwnd", GUICtrlGetHandle(-1))
    Return $aRet[0]
EndFunc

Func _maximize()
    GUISetState(@SW_RESTORE, $GUI)
    GUISetState(@SW_SHOW, $GUI)
	GUISetState(@SW_RESTORE, $GUI)
EndFunc

;~ apply desired IP settings
Func _apply()
	Local $ret, $fwstate
	$ErrorState = 0
	GuiCtrlSetData( $statusset_lab, "Applying Settings..." )
	$adapter_sel = GUICtrlRead( $connection )
	If GUICtrlRead( $ck_disable) = $GUI_CHECKED Then
		$ret = _AdapterMod($adapter_sel, 0)		; disable the adapter
		If $ret = 1 Then
			_AdapterModErrors(101)
			$ErrorState = 1
			Return 1
		EndIf
		If $ret = 2 Then
			_AdapterModErrors(102)
			$ErrorState = 1
			Return 1
		EndIf
		If $ret = 3 Then
			_AdapterModErrors(103)
			$ErrorState = 1
			Return 1
		EndIf
		If $ret = 4 Then
			_AdapterModErrors(104)
			$ErrorState = 1
			Return 1
		EndIf
	ELSE
		_AdapterMod($adapter_sel, 1)		; enable the adapter
		If $ret = 1 Then
			_AdapterModErrors(101)
			$ErrorState = 1
			Return 1
		EndIf
		If $ret = 2 Then
			_AdapterModErrors(102)
			$ErrorState = 1
			Return 1
		EndIf
		If $ret = 3 Then
			_AdapterModErrors(103)
			$ErrorState = 1
			Return 1
		EndIf
		If $ret = 4 Then
			_AdapterModErrors(104)
			$ErrorState = 1
			Return 1
		EndIf
		If (GUICtrlRead( $rd_ipmanual) = $GUI_CHECKED) Then
			$ret = _checkinput()
			If $ret = 1 Then
				Return 1
			EndIf
			$ret = submit_ip()
			If $ret = 1 Then
				Return 1
			EndIf
		Else
			$ret = dhcp_ip()
			If $ret = 1 Then
				Return 1
			EndIf
		EndIf
		If (GUICtrlRead( $rd_dnsmanual) = $GUI_CHECKED) Then
			$ret = _checkinput()
			If $ret = 1 Then
				Return 1
			EndIf
			$ret = submit_dns()
			If $ret = 1 Then
				Return 1
			EndIf
		Else
			$ret = dhcp_dns()
			If $ret = 1 Then
				Return 1
			EndIf
		EndIf
	EndIf
	$fwstate = _GetFwState()
	If GUICtrlRead( $ck_disablefw) = $GUI_CHECKED AND $fwstate = 1 Then
		firewall_dis()
	ElseIf GUICtrlRead( $ck_disablefw) = $GUI_UNCHECKED AND $fwstate = 0 Then
		firewall_en()
	EndIf

	_currentStats()	; Get current network settings
	Return
EndFunc
Func _radios()
	forceradios(0)
EndFunc
Func _refresh()
	$ErrorState = 0
	_refreshpnames()
	_currentStats(1)	; Get current network settings
EndFunc
Func _refreshalt()
	$ErrorState = 0
	_refreshpnames()
	_currentStats()	; Get current network settings
EndFunc
Func _clear()
	GUICtrlSetData( $newip, "")
	GUICtrlSetData( $newsm, "")
	GUICtrlSetData( $newgw, "")
	GUICtrlSetData( $dnsp, "")
	GUICtrlSetData( $dnsa, "")
	GUICtrlSetState( $newip, $GUI_FOCUS)
EndFunc
Func _send2tray()
	GUISetState(@SW_MINIMIZE, $GUI)
	GUISetState(@SW_HIDE, $GUI)
EndFunc
Func _minimize()
	GUISetState(@SW_MINIMIZE, $GUI)
EndFunc
Func _about()
	Local $bt_AboutOk, $lb_Heading, $lb_date, $lb_version, $lb_info, $lb_sig, $pic, $lb_license, $GFLine

	$AboutChild = GUICreate( "About Simple IP Config", 275*$dr, 235*$dr, @DesktopWidth/2-275*$dr/2, @DesktopHeight/2-235*$dr/2)
	GUISetOnEvent( $GUI_EVENT_CLOSE, "_closerAbout")

	$pic = GUICtrlCreateIcon('', 0, 4*$dr, 20*$dr, 96, 96)
	_SetIcon($pic, $winname & " " & $winversion & ".exe", 4, 96, 96)

	$lb_Heading = GUICtrlCreateLabel( "Simple IP Config", 105*$dr, 30*$dr, 180*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSizeLarge, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $MyGlobalFontBKColor)
	$lb_version = GUICtrlCreateLabel( "Version: " & $winversion, 105*$dr, 50*$dr, 180*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $MyGlobalFontBKColor)
	$lb_date = GUICtrlCreateLabel( $windate, 105*$dr, 70*$dr, 180*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $MyGlobalFontBKColor)
	$lb_sig = GUICtrlCreateLabel( "By: Kurtis Liggett", 105*$dr, 90*$dr, 180*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $MyGlobalFontBKColor)

	$lb_info = GUICtrlCreateLabel( "Easily change common network parameters.", 10*$dr, 130*$dr, 290*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $MyGlobalFontBKColor)

	$GFLine = GUICtrlCreateGraphic( 0, 160*$dr, 0,0)
	_DrawLine( -1, 0, 0, 275*$dr, 0, 1, 0xa6a6a6)
	GUICtrlSetState( -1, $GUI_DISABLE)
	$lb_license = GUICtrlCreateLabel( "License: GNU GPLv3 (Free for All)", 10*$dr, 170*$dr, 255*$dr, 20*$dr)
	_SetMyFont( -1, $MYGlobalFontSize, -1, -1, $MyGlobalFontName, 4, $MyGlobalFontColor, $MyGlobalFontBKColor)

	$bt_AboutOk = GUICtrlCreateButton( "OK", 15*$dr, 200*$dr, 50*$dr, 22*$dr)
	GUICtrlSetOnEvent( -1, "_closerAbout")

	GUISetState(@SW_DISABLE, $GUI)
	GUISetState(@SW_SHOW, $AboutChild)
EndFunc

Func _closerAbout()
	GUISetState(@SW_ENABLE, $GUI)
	GUIDelete( $AboutChild )

	If WinGetState( $winname & " " & $winversion)<>21 Then
		GUISetState(@SW_SHOW, $GUI)
	EndIf
EndFunc

Func _onlinehelp()
	ShellExecute ("http://sourceforge.net/p/simpleipconfig/docs/Home/")
EndFunc

Func _Enter()
	Local $foc
	$foc = ControlGetFocus( $winname & " " & $winversion )
	If $foc = "Edit15" Or $foc = "Edit16" Or $foc = "Edit17" Or $foc = "Edit18" Or $foc = "Edit19" Then
		_apply()
	ElseIf $foc = "Button6" Or $foc = "Button7" Or $foc = "Button8" Or $foc = "Button9" Then
		_apply()
	ElseIf $foc = "ComboBox1" Then
		If _GUICtrlComboBox_GetDroppedState ( $connection ) Then
			Send("^{ENTER}")
		Else
			_currentStats()	; Get current network settings
		EndIf
	ElseIf $foc = "SysListView321" Then
		If StringReplace( GUICtrlRead(GUICtrlRead($plistview)), "|", "") = $pname Then
			_apply()
		Else
			_setprof()
		EndIf
	EndIf
;~ 	MsgBox( 0, "", ControlGetFocus( $winname & " " & $winversion ))		; need to check this each time new controls are added
EndFunc

; this function used to handle combobox click
Func _WM_COMMAND($hWnd, $msg, $wParam, $lParam)
    Local $iIDFrom = BitAND($wParam, 0x0000FFFF) ; LoWord - this gives the control which sent the message
    Local $iCode = BitShift($wParam, 16)     ; HiWord - this gives the message that was sent
    If $iCode = $EN_CHANGE Then ; check if change was detected
        Switch $iIDFrom ; See if it comes from one of the inputs
            Case $newip, $newsm, $newgw, $dnsa, $dnsp
				GUICtrlSendToDummy($inputdummy)
		EndSwitch
	ElseIf $iCode = $CBN_CLOSEUP Then	; check if combo was closed
		Switch $iIDFrom
            Case $connection
				GUICtrlSendToDummy($combodummy)
		EndSwitch
    EndIf
    Return $GUI_RUNDEFMSG
EndFunc
Func _enablesave()
	Local $foc, $tip, $temp

	$foc = ControlGetFocus( $winname & " " & $winversion )
	If $foc <> "SysListView321" Then
		If GUICtrlGetState( $bt_save ) = $GUI_DISABLE Then
			GUICtrlSetState( $bt_save, $GUI_ENABLE )
		EndIf

		If $foc = "Edit15" Then
			$tip = GUICtrlRead( $newip )
			If $tip <> $lastip Then
				If StringRegExp($tip, '\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}', 0) = 1 Then
					$temp = StringLeft( $tip, StringInStr ( $tip, ".", -1, 3 ) )
					If $temp <> 0 Then
						If $autogw = 1 Then
							GUICtrlSetData( $newgw, $temp & "1" )
						EndIf
						If $autodns = 1 Then
							GUICtrlSetData( $dnsp, $temp & "1" )
							GUICtrlSetData( $dnsa, $temp & "1" )
						EndIf
					Else
						Return
					EndIf
				EndIf
			EndIf
			$lastip = $tip
		EndIf
	EndIf
;~ 	MsgBox(0,"",$foc)	;used to get control classnameNN
EndFunc

Func _closer()
	Exit
EndFunc
Func _closerchild()
	GUISetState(@SW_ENABLE, $GUI)
	GUIDelete( $optionchild )
	GUISetState(@SW_SHOW, $GUI)
EndFunc
#EndRegion ; userfunctions

#Region - Apply

; force radio selection
Func forceradios($save_disable)
	If (GUICtrlRead( $ck_disable) = $GUI_CHECKED) Then
		GUICtrlSetState( $rd_ipauto,$GUI_DISABLE )
		GUICtrlSetState( $rd_ipmanual,$GUI_DISABLE )
		GUICtrlSetState( $rd_dnsauto,$GUI_DISABLE )
		GUICtrlSetState( $rd_dnsmanual,$GUI_DISABLE )
		GUICtrlSetState( $lb_ip,$GUI_DISABLE )
		GUICtrlSetState( $lb_sm,$GUI_DISABLE )
		GUICtrlSetState( $lb_gw,$GUI_DISABLE )
		GUICtrlSetState( $newip,$GUI_DISABLE )
		GUICtrlSetState( $newsm,$GUI_DISABLE )
		GUICtrlSetState( $newgw,$GUI_DISABLE )
		GUICtrlSetState( $lb_dnsp,$GUI_DISABLE )
		GUICtrlSetState( $lb_dnsa,$GUI_DISABLE )
		GUICtrlSetState( $dnsp,$GUI_DISABLE )
		GUICtrlSetState( $dnsa,$GUI_DISABLE )
	Else
		If (GUICtrlRead( $rd_ipmanual) = $GUI_CHECKED) Then
			GUICtrlSetState( $rd_ipauto,$GUI_ENABLE )
			GUICtrlSetState( $rd_ipmanual,$GUI_ENABLE )
			GUICtrlSetState( $rd_dnsmanual,$GUI_ENABLE )
			GUICtrlSetState( $rd_dnsmanual, $GUI_CHECKED)
			GUICtrlSetState( $rd_dnsauto,$GUI_DISABLE )
			GUICtrlSetState( $lb_ip,$GUI_ENABLE )
			GUICtrlSetState( $lb_sm,$GUI_ENABLE )
			GUICtrlSetState( $lb_gw,$GUI_ENABLE )
			GUICtrlSetState( $lb_dnsp,$GUI_ENABLE )
			GUICtrlSetState( $lb_dnsa,$GUI_ENABLE )
			GUICtrlSetState( $newip,$GUI_ENABLE )
			GUICtrlSetState( $newsm,$GUI_ENABLE )
			GUICtrlSetState( $newgw,$GUI_ENABLE )
			GUICtrlSetState( $dnsp,$GUI_ENABLE )
			GUICtrlSetState( $dnsa,$GUI_ENABLE )
		Else
			GUICtrlSetState( $rd_ipauto,$GUI_ENABLE )
			GUICtrlSetState( $rd_ipmanual,$GUI_ENABLE )
			GUICtrlSetState( $rd_dnsmanual,$GUI_ENABLE )
			GUICtrlSetState( $rd_dnsauto,$GUI_ENABLE )
			GUICtrlSetState( $lb_ip,$GUI_DISABLE )
			GUICtrlSetState( $lb_sm,$GUI_DISABLE )
			GUICtrlSetState( $lb_gw,$GUI_DISABLE )
			GUICtrlSetState( $newip,$GUI_DISABLE )
			GUICtrlSetState( $newsm,$GUI_DISABLE )
			GUICtrlSetState( $newgw,$GUI_DISABLE )
			GUICtrlSetData( $newip, "")
			GUICtrlSetData( $newsm, "")
			GUICtrlSetData( $newgw, "")
		EndIf
		If (GUICtrlRead( $rd_dnsmanual) = $GUI_CHECKED) Then
			GUICtrlSetState( $lb_dnsp,$GUI_ENABLE )
			GUICtrlSetState( $lb_dnsa,$GUI_ENABLE )
			GUICtrlSetState( $dnsp,$GUI_ENABLE )
			GUICtrlSetState( $dnsa,$GUI_ENABLE )
		Else
			GUICtrlSetState( $lb_dnsp,$GUI_DISABLE )
			GUICtrlSetState( $lb_dnsa,$GUI_DISABLE )
			GUICtrlSetState( $dnsp,$GUI_DISABLE )
			GUICtrlSetState( $dnsa,$GUI_DISABLE )
			GUICtrlSetData( $dnsp, "")
			GUICtrlSetData( $dnsa, "")
		EndIf
	EndIf
	If $save_disable = 0 Then
		GUICtrlSetState( $bt_save, $GUI_ENABLE )
	Else
		GUICtrlSetState( $bt_save, $GUI_DISABLE )
	EndIf
EndFunc

; check input format then apply
Func _checkinput()
	If (GUICtrlRead( $rd_ipmanual) = $GUI_CHECKED) Then
		$ip = GUICtrlRead( $newip )
		If StringRegExp($ip, '\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}', 0) = 0 Then	; checking number format
			$ErrorState = 1
			MsgBox(48, "Error", "Error Code 1" & @CR & "Invalid IP Address")
			GuiCtrlSetData( $statusset_lab, "IP was not set")
			Return 1
		EndIf
		$sm = GUICtrlRead( $newsm )
		If StringRegExp($sm, '\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}', 0) = 0 Then
			$ErrorState = 1
			MsgBox(48, "Error", "Error Code 2" & @CR & "Invalid Subnet Mask")
			GuiCtrlSetData( $statusset_lab, "IP was not set")
			Return 1
		EndIf
		$gw = GUICtrlRead( $newgw )
		If StringRegExp($gw, '\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}', 0) = 0 Then
			If $gw <> "" And $gw <> "---.---.---.---" Then
				$ErrorState = 1
				MsgBox(48, "Error", "Error Code 3" & @CR & "Invalid Gateway")
				GuiCtrlSetData( $statusset_lab, "IP was not set")
				Return 1
			EndIf
		EndIf
	EndIf
	If (GUICtrlRead( $rd_dnsmanual) = $GUI_CHECKED) Then
		$dns1 = GUICtrlRead( $dnsp )
		If StringRegExp($dns1, '\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}', 0) = 0 Then
			If $dns1 <> "" And $dns1 <> "---.---.---.---" Then
				$ErrorState = 1
				MsgBox(48, "Error", "Error Code 4" & @CR & "Invalid primary DNS server")
				GuiCtrlSetData( $statusset_lab, "IP was not set")
				Return 1
			EndIf
		EndIf
		$dns2 = GUICtrlRead( $dnsa )
		If StringRegExp($dns2, '\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}', 0) = 0 Then
			If $dns2 <> "" And $dns2 <> "---.---.---.---" Then
				$ErrorState = 1
				MsgBox(48, "Error", "Error Code 5" & @CR & "Invalid alternate DNS server")
				GuiCtrlSetData( $statusset_lab, "IP was not set")
				Return 1
			EndIf
		EndIf
	EndIf
	Return
EndFunc
Func submit_ip()
	Local $colItems, $Adapter_caption, $intReturn
	Local $arrip[1]
	Local $arrsm[1]
	Local $arrgw[1]
	$arrip[0] = $ip
	$arrsm[0] = $sm
	$arrgw[0] = $gw

	; check if gateway is given, change IP
	$colItems = $objWMI.ExecQuery("SELECT caption, NetConnectionID FROM Win32_NetworkAdapter WHERE NetConnectionID=""" & $adapter_sel & """", "WQL", $wbemFlagReturnImmediately + $wbemFlagForwardOnly)
	for $objItem in $colItems
		$Adapter_caption = $objItem.caption
		ExitLoop
	Next
	$colItems = $objWMI.ExecQuery("SELECT caption FROM Win32_NetworkAdapterConfiguration WHERE caption=""" & $Adapter_caption & """", "WQL", $wbemFlagReturnImmediately + $wbemFlagForwardOnly)
	For $objItem In $colItems
		$intReturn = $objItem.EnableStatic($arrip, $arrsm)
		If $intReturn <> 0 Then
			$ErrorState = 1
			_wmierror(6, $intReturn) ; error code 6
			Return 1
		EndIf
		ExitLoop
	Next
	If StringRegExp($gw, '\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}', 0) = 1  Then
		$colItems = $objWMI.ExecQuery("SELECT caption FROM Win32_NetworkAdapterConfiguration WHERE caption=""" & $Adapter_caption & """", "WQL", $wbemFlagReturnImmediately + $wbemFlagForwardOnly)
		For $objItem In $colItems
			$intReturn = $objItem.SetGateways($arrgw)
		If $intReturn <> 0 Then
			$ErrorState = 1
			_wmierror(7, $intReturn) ; error code 7
			Return 1
		EndIf
			ExitLoop
		Next
	EndIf
	Return
EndFunc

;~ enable dhcp
Func dhcp_ip()
	Local $arrgw[1]
	Local $colItems, $Adapter_caption, $intReturn
	$arrgw[0] = $newip
	$colItems = $objWMI.ExecQuery("SELECT caption, NetConnectionID FROM Win32_NetworkAdapter WHERE NetConnectionID=""" & $adapter_sel & """", "WQL", $wbemFlagReturnImmediately + $wbemFlagForwardOnly)
	for $objItem in $colItems
		$Adapter_caption = $objItem.caption
		ExitLoop
	Next
	$colItems = $objWMI.ExecQuery("SELECT caption FROM Win32_NetworkAdapterConfiguration WHERE caption=""" & $Adapter_caption & """", "WQL", $wbemFlagReturnImmediately + $wbemFlagForwardOnly)
	For $objItem In $colItems
		$intReturn = $objItem.EnableDHCP
		If $intReturn <> 0 Then
			$ErrorState = 1
			_wmierror(9, $intReturn) ; error code 9
			Return 1
		EndIf
		ExitLoop
	Next
	Return
EndFunc

;~ apply dns settings
Func submit_dns()
	Local $arrdns[1]=[0]
	Local $arrnew
	Local $colItems, $Adapter_caption, $intReturn

	; check primary dns
	If StringRegExp($dns1, '\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}', 0) = 1  Then
		$arrdns[0] = $dns1
		If StringRegExp($dns2, '\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}', 0) = 1 Then
			ReDim $arrdns[2]
			$arrdns[1] = $dns2
		EndIf
		$colItems = $objWMI.ExecQuery("SELECT caption, NetConnectionID FROM Win32_NetworkAdapter WHERE NetConnectionID=""" & $adapter_sel & """", "WQL", $wbemFlagReturnImmediately + $wbemFlagForwardOnly)
		for $objItem in $colItems
			$Adapter_caption = $objItem.caption
			ExitLoop
		Next
		$colItems = $objWMI.ExecQuery("SELECT caption FROM Win32_NetworkAdapterConfiguration WHERE caption=""" & $Adapter_caption & """", "WQL", $wbemFlagReturnImmediately + $wbemFlagForwardOnly)
		For $objItem In $colItems
			$intReturn = $objItem.SetDNSServerSearchOrder($arrdns)
		If $intReturn <> 0 Then
			$ErrorState = 1
			_wmierror(10, $intReturn) ; error code 10
			Return 1
		EndIf
			ExitLoop
		Next
	EndIf
	Return
EndFunc

;~ enable dhcp for dns
Func dhcp_dns()
	Local $colItems, $Adapter_caption, $intReturn
	$colItems = $objWMI.ExecQuery("SELECT caption, NetConnectionID FROM Win32_NetworkAdapter WHERE NetConnectionID=""" & $adapter_sel & """", "WQL", $wbemFlagReturnImmediately + $wbemFlagForwardOnly)
	for $objItem in $colItems
		$Adapter_caption = $objItem.caption
		ExitLoop
	Next
	$colItems = $objWMI.ExecQuery("SELECT caption FROM Win32_NetworkAdapterConfiguration WHERE caption=""" & $Adapter_caption & """", "WQL", $wbemFlagReturnImmediately + $wbemFlagForwardOnly)
	For $objItem In $colItems
		$intReturn = $objItem.SetDNSServerSearchOrder()
		If $intReturn <> 0 Then
			$ErrorState = 1
			_wmierror(11, $intReturn) ; error code 11
			Return 1
		EndIf
		ExitLoop
	Next
	Return
EndFunc

; get current firewall state
Func _GetFwState()
	Local $run, $StdOutr
	$StdOutr = ""
	$run = Run(@ComSpec & " /c " & 'netsh advfirewall show currentprofile state', "", @SW_HIDE, 6) ; 6 = $STDERR_CHILD+$STDOUT_CHILD
	While 1
        $StdOutr &= StdoutRead($run)
        If @error Then ExitLoop
	Wend

;~ 	MsgBox( 0, "", $StdOutr)
	If StringInStr( $StdOutr, "ON" ) Then
		Return 1	; firewall is on
	Else
		Return 0	; firewall is off
	EndIf
EndFunc

; enable firewall
Func firewall_en()
	Local $run
	$run = RunWait(@ComSpec & " /c " & 'netsh advfirewall set currentprofile state on', "", @SW_HIDE)
EndFunc
Func firewall_dis()
	Local $run
	$run = RunWait(@ComSpec & " /c " & 'netsh advfirewall set currentprofile state off', "", @SW_HIDE)
EndFunc

; load current settings into profile
Func _SetCurrent()
	Local $stats, $ret

	GuiCtrlSetData( $statusset_lab, "Pulling Info..." )
	$adapter_sel = GUICtrlRead( $connection )
	$stats = _getIPs($adapter_sel)
	; need to implement an error checking here
	If StringStripWS ( $stats[0], 8 ) = "" Then
		$ErrorState = 1
		GuiCtrlSetData( $statusset_lab, "Adapter not connected")
		Return
	ElseIf StringRegExp($stats[0], '169\.{1}\d{1,3}\.{1}\d{1,3}\.{1}\d{1,3}', 0) = 1 Then
		$ErrorState = 1
		GuiCtrlSetData( $statusset_lab, "DHCP Server was not found or is not ready.")
		Return
	ElseIf $stats[6] = "Disabled" Then
		$ErrorState = 1
		GuiCtrlSetData( $statusset_lab, "Adapter is disabled.")
		Return
	EndIf

	If $stats[5] <> "Static" Then
		GUICtrlSetState( $rd_ipauto, $GUI_CHECKED )
		GUICtrlSetState( $rd_dnsauto, $GUI_CHECKED )
		forceradios(0)
		GuiCtrlSetData( $newip,		$stats[0] )
		GuiCtrlSetData( $newsm,		$stats[1] )
		GuiCtrlSetData( $newgw,		$stats[2] )
		GuiCtrlSetData( $dnsp,		$stats[3] )
		GuiCtrlSetData( $dnsa,		$stats[4] )
	Else
		GUICtrlSetState( $rd_ipmanual, $GUI_CHECKED )
		forceradios(0)
		GuiCtrlSetData( $newip,		$stats[0] )
		GuiCtrlSetData( $newsm,		$stats[1] )
		GuiCtrlSetData( $newgw,		$stats[2] )
		GuiCtrlSetData( $dnsp,		$stats[3] )
		GuiCtrlSetData( $dnsa,		$stats[4] )
	EndIf

;~ 	If $stats[6] = "Enabled" Then
;~ 		GUICtrlSetState( $ck_disable, $GUI_UNCHECKED )
;~ 	Else
;~ 		GUICtrlSetState( $ck_disable, $GUI_CHECKED )
;~ 	EndIf

	If $ErrorState = 0 Then
		GuiCtrlSetData( $statusset_lab, "Ready" )
	EndIf
EndFunc

#EndRegion ;apply

#Region - Profiles
; load / create profile functions
Func _refreshpnames()
	Local $plen, $profarr
	_GUICtrlListView_DeleteAllItems(GUICtrlGetHandle($plistview))
	; check for profile file
	If Not FileExists( $pFileLoc ) Then
		_ConfigFile()
		Return 1
	EndIf

	; load profile names
	$profarr = IniReadSectionNames( $pFileLoc )
	If @error Then
		_ConfigFile(51)
		Return 1
	EndIf
	$plen = $profarr[0]
		; build list
	For $k=2 to $plen
		GUICtrlCreateListViewItem( $profarr[$k], $plistview )
		GUICtrlSetOnEvent( -1, "_setprof" )
	Next
	GUICtrlSetState($bt_save, $GUI_DISABLE)
EndFunc
Func _setprof()
	Local $infoarr, $numel, $psections
	Local $propindex[15] = [0]
	Local $propflag = 0
	Local $ans = 0

	If Not FileExists( "profiles.ini" ) Then
		_ConfigFile()
		Return 1
	EndIf
	$psections = IniReadSectionNames( "profiles.ini" )
	If $psections[0] = 1 Then
		GUICtrlCreateListViewItem( "No profiles found", $plistview )
		Return	; don't load any settings if there are no profiles
	EndIf
	$psections = 0
	$pname = StringReplace( GUICtrlRead(GUICtrlRead($plistview)), "|", "")
	$infoarr = IniReadSection( "profiles.ini", $pname )
	If @error Then
		_ConfigFile(52)
		Return 1
	EndIf
	$numel = $infoarr[0][0]

	; assign property indices
	For $i=1 To $numel
		If $infoarr[$i][0] = "DHCPenable" Then
			$propindex[1] = $i
		ElseIf $infoarr[$i][0] = "DNSAuto" Then
			$propindex[2] = $i
		ElseIf $infoarr[$i][0] = "IP Address" Then
			$propindex[3] = $i
		ElseIf $infoarr[$i][0] = "Subnet Mask" Then
			$propindex[4] = $i
		ElseIf $infoarr[$i][0] = "Gateway" Then
			$propindex[5] = $i
		ElseIf $infoarr[$i][0] = "PDNS" Then
			$propindex[6] = $i
		ElseIf $infoarr[$i][0] = "ADNS" Then
			$propindex[7] = $i
		ElseIf $infoarr[$i][0] = "DisableAdapter" Then
			$propindex[8] = $i
		ElseIf $infoarr[$i][0] = "DisableFirewall" Then
			$propindex[9] = $i
		EndIf
	Next

	; check if property was found in config file
	For $i=1 To $numel
		If $propindex[$i] = 0 Then
			$propflag = 1
			ExitLoop
		EndIf
	Next
	If $propflag = 1 Then
		$ans = MsgBox( 4, "Error", "Config File is corrupt." & @CR & "Attempt to repair?", Default, $gui)
		If $ans = 7 Then	; no
			_ConfigFile(53)
			Return 1
		Else
			For $i=1 To UBound( $propindex )-1
				If $propindex[$i] = 0 Then
					If $i = 1 Then
						IniWrite("profiles.ini", $pname, "DHCPenable", "FALSE")
					ElseIf $i = 2 Then
						IniWrite("profiles.ini", $pname, "DNSAuto", "FALSE")
					ElseIf $i = 3 Then
						IniWrite("profiles.ini", $pname, "IP Address", "FALSE")
					ElseIf $i = 4 Then
						IniWrite("profiles.ini", $pname, "Subnet Mask", "FALSE")
					ElseIf $i = 5 Then
						IniWrite("profiles.ini", $pname, "Gateway", "FALSE")
					ElseIf $i = 6 Then
						IniWrite("profiles.ini", $pname, "PDNS", "FALSE")
					ElseIf $i = 7 Then
						IniWrite("profiles.ini", $pname, "ADNS", "FALSE")
					ElseIf $i = 8 Then
						IniWrite("profiles.ini", $pname, "DisableAdapter", "FALSE")
					ElseIf $i = 9 Then
						IniWrite("profiles.ini", $pname, "DisableFirewall", "FALSE")
					EndIf
				EndIf
			Next
		EndIf
	EndIf
	For $i=1 To $numel
		If $infoarr[$i][0] = "DHCPenable" Then
			$propindex[1] = $i
		ElseIf $infoarr[$i][0] = "DNSAuto" Then
			$propindex[2] = $i
		ElseIf $infoarr[$i][0] = "IP Address" Then
			$propindex[3] = $i
		ElseIf $infoarr[$i][0] = "Subnet Mask" Then
			$propindex[4] = $i
		ElseIf $infoarr[$i][0] = "Gateway" Then
			$propindex[5] = $i
		ElseIf $infoarr[$i][0] = "PDNS" Then
			$propindex[6] = $i
		ElseIf $infoarr[$i][0] = "ADNS" Then
			$propindex[7] = $i
		ElseIf $infoarr[$i][0] = "DisableAdapter" Then
			$propindex[8] = $i
		ElseIf $infoarr[$i][0] = "DisableFirewall" Then
			$propindex[9] = $i
		EndIf
	Next
	If $infoarr[$propindex[1]][1]="TRUE" Then
		GUICtrlSetState( $rd_ipauto, $GUI_CHECKED )
		If $infoarr[$propindex[2]][1]="TRUE" Then
			GUICtrlSetState( $rd_dnsauto, $GUI_CHECKED )
			forceradios(1)
		Else
			GUICtrlSetState( $rd_dnsmanual, $GUI_CHECKED )
			forceradios(1)
			If $propindex[6] <> 0 Then
				GUICtrlSetData( $dnsp, $infoarr[$propindex[6]][1] )
			Else
				GUICtrlSetData( $dnsp, "" )
			EndIf
			If $propindex[7] <> 0 Then
				GUICtrlSetData( $dnsa, $infoarr[$propindex[7]][1] )
			Else
				GUICtrlSetData( $dnsa, "" )
			EndIf
		EndIf
	Else
		GUICtrlSetState( $rd_ipmanual, $GUI_CHECKED )
		forceradios(1)
		If $propindex[3] <> 0 Then
			GUICtrlSetData( $newip, $infoarr[$propindex[3]][1] )
		Else
			GUICtrlSetData( $newip, "" )
		EndIf
		If $propindex[4] <> 0 Then
			GUICtrlSetData( $newsm, $infoarr[$propindex[4]][1] )
		Else
			GUICtrlSetData( $newsm, "" )
		EndIf
		If $propindex[5] <> 0 Then
			GUICtrlSetData( $newgw, $infoarr[$propindex[5]][1] )
		Else
			GUICtrlSetData( $newgw, "" )
		EndIf
		If $propindex[6] <> 0 Then
			GUICtrlSetData( $dnsp, $infoarr[$propindex[6]][1] )
		Else
			GUICtrlSetData( $dnsp, "" )
		EndIf
		If $propindex[7] <> 0 Then
			GUICtrlSetData( $dnsa, $infoarr[$propindex[7]][1] )
		Else
			GUICtrlSetData( $dnsa, "" )
		EndIf
	EndIf
	If $infoarr[$propindex[8]][1]="TRUE" Then
		GUICtrlSetState( $ck_disable, $GUI_CHECKED )
		forceradios(1)
	Else
		GUICtrlSetState( $ck_disable, $GUI_UNCHECKED )
		forceradios(1)
	EndIf
	If $infoarr[$propindex[9]][1]="TRUE" Then
		GUICtrlSetState( $ck_disablefw, $GUI_CHECKED )
	Else
		GUICtrlSetState( $ck_disablefw, $GUI_UNCHECKED )
	EndIf

;~ 	$profile_click = 1;
EndFunc ;_setprof
Func _save()
	Local $auto1, $auto2, $disabler, $disablerfw, $data, $writer, $psections
	If Not FileExists( "profiles.ini" ) Then
		_FileHandler()
		Return
	EndIf
	$psections = IniReadSectionNames( "profiles.ini" )
	If $psections[0] = 1 Then
		_saveas()
		Return
	EndIf
	$psections = 0
	If IsInt(GUICtrlRead(GUICtrlRead($plistview))) Then
		MsgBox( 0, "Save Profile", "Please select a profile to save to.", Default, $gui)
		Return
	EndIf
	$auto1 = 0
	$auto2 = 0
	If (GUICtrlRead( $rd_ipmanual) = $GUI_CHECKED) Then
		$auto1 = "FALSE"
	Else
		$auto1 = "TRUE"
	EndIf
	If (GUICtrlRead( $rd_dnsmanual) = $GUI_CHECKED) Then
		$auto2 = "FALSE"
	Else
		$auto2 = "TRUE"
	EndIf
	If (GUICtrlRead( $ck_disable) = $GUI_UNCHECKED) Then
		$disabler = "FALSE"
	Else
		$disabler = "TRUE"
	EndIf
	If (GUICtrlRead( $ck_disablefw) = $GUI_UNCHECKED) Then
		$disablerfw = "FALSE"
	Else
		$disablerfw = "TRUE"
	EndIf
	$data = "DHCPenable = " & $auto1 & @CRLF & _
		"DNSAuto = " & $auto2 & @CRLF & _
		"IP Address = " & GUICtrlRead( $newip ) & @CRLF & _
		"Subnet Mask = " & GUICtrlRead( $newsm ) & @CRLF & _
		"Gateway = " & GUICtrlRead( $newgw ) & @CRLF & _
		"PDNS = " & GUICtrlRead( $dnsp ) & @CRLF & _
		"ADNS = " & GUICtrlRead( $dnsa ) & @CRLF & _
		"DisableAdapter = " & $disabler & @CRLF & _
		"DisableFirewall = " & $disablerfw
	$writer = IniWriteSection( "profiles.ini", $pname, $data )
	If $writer = 0 Then
		_ConfigFile(54)
		Return 1
	ElseIf @error Then
		_ConfigFile(55)
		Return 1
	EndIf
	GUICtrlSetState($bt_save, $GUI_DISABLE)
EndFunc	; _save
Func _saveas()
	Local $ans, $pfile, $ovrw, $data, $writer, $newpname, $profarr, $auto1, $auto2, $disabler, $disablerfw
	If Not FileExists( $pFileLoc ) Then
		_FileHandler()
		Return
	EndIf
	$newpname = InputBox( "Profile Name", "Please enter new profile name.", Default, " M", Default, 150*$dr, Default, Default, Default, $gui)
	If @error = 1 Then
		Return
	EndIf
	$profarr = IniReadSectionNames( "profiles.ini" )
	For $i=2 To $profarr[0]
		If $newpname = $profarr[$i] Then
			$ovrw = MsgBox( 4, "Question", "Overwrite existing profile " & $pname & "?", Default, $gui)
			If $ovrw = 7 Then
				Return
			EndIf
		EndIf
	Next
	$auto1 = 0
	$auto2 = 0
	If (GUICtrlRead( $rd_ipmanual) = $GUI_CHECKED) Then
		$auto1 = "FALSE"
	Else
		$auto1 = "TRUE"
	EndIf
	If (GUICtrlRead( $rd_dnsmanual) = $GUI_CHECKED) Then
		$auto2 = "FALSE"
	Else
		$auto2 = "TRUE"
	EndIf
	If (GUICtrlRead( $ck_disable) = $GUI_UNCHECKED) Then
		$disabler = "FALSE"
	Else
		$disabler = "TRUE"
	EndIf
	If (GUICtrlRead( $ck_disablefw) = $GUI_UNCHECKED) Then
		$disablerfw = "FALSE"
	Else
		$disablerfw = "TRUE"
	EndIf
	$data = "DHCPenable = " & $auto1 & @CRLF & _
		"DNSAuto = " & $auto2 & @CRLF & _
		"IP Address = " & GUICtrlRead( $newip ) & @CRLF & _
		"Subnet Mask = " & GUICtrlRead( $newsm ) & @CRLF & _
		"Gateway = " & GUICtrlRead( $newgw ) & @CRLF & _
		"PDNS = " & GUICtrlRead( $dnsp ) & @CRLF & _
		"ADNS = " & GUICtrlRead( $dnsa ) & @CRLF & _
		"DisableAdapter = " & $disabler & @CRLF & _
		"DisableFirewall = " & $disablerfw
	$writer = IniWriteSection( "profiles.ini", $newpname, $data )
	If $writer = 0 Then
		_ConfigFile(56)
		Return 1
	ElseIf @error Then
		_ConfigFile(57)
		Return 1
	EndIf
	_refreshpnames()
	GUICtrlSetState($bt_save, $GUI_DISABLE)
EndFunc	; _saveas
Func _deletekey()
	Local $foc
	$foc = ControlGetFocus( $winname & " " & $winversion )
	If $foc = "SysListView321" Then
		_delete()
	Else
		GUISetAccelerators(0)
		Send( "{DEL}" )
		GUISetAccelerators($accels)
	EndIf
;~ 	MsgBox( 0, "", ControlGetFocus( $winname & " " & $winversion ))
EndFunc	; deletekey
Func _delete()
	Local $index, $pname, $writer, $icount
	If Not FileExists( "profiles.ini" ) Then
		_ConfigFile()
		Return 1
	EndIf
	$index = ControlListView( $winname & " " & $winversion, "", $plistview, "GetSelected" )
	If ControlListView( $winname & " " & $winversion, "", $plistview, "GetItemCount")=1 Then
		MsgBox( 48, "Error", "There must be at least 1 profile.", Default, $gui )
		Return 1
	EndIf
	$pname = StringReplace( GUICtrlRead(GUICtrlRead($plistview)), "|", "")
	If IsInt(GUICtrlRead(GUICtrlRead($plistview))) Then
		MsgBox( 0, "Profile Delete", "Please select a profile to delete.", Default, $gui)
		Return 1
	EndIf
	$writer = IniDelete( "profiles.ini", $pname )
	If $writer = 0 Then
		_ConfigFile(58)
		Return 1
	EndIf
	_refreshpnames()
	$icount = ControlListView( $winname & " " & $winversion, "", $plistview, "GetItemCount" )
	If $index > $icount-1 Then
		$index = $icount-1
	EndIf
	ControlListView( $winname & " " & $winversion, "", $plistview, "Select", $index )
	_setprof()
EndFunc
Func _Rename()
	Local $index, $pname, $writer, $icount, $newpname, $i, $res, $filetext, $file
	If Not FileExists( "profiles.ini" ) Then
		_ConfigFile()
		Return 1
	EndIf
	$icount = ControlListView( $winname & " " & $winversion, "", $plistview, "GetItemCount" )	; get number of profiles
	$index = ControlListView( $winname & " " & $winversion, "", $plistview, "GetSelected" )		; get index of selected profile
	$pname = StringReplace( GUICtrlRead(GUICtrlRead($plistview)), "|", "")
	If IsInt(GUICtrlRead(GUICtrlRead($plistview))) Then
		MsgBox( 0, "Profile Rename", "Please select a profile to rename.", Default, $gui)
		Return 1
	EndIf

	$newpname = InputBox( "Profile Name", "Please enter new profile name.", Default, " M", Default, 150*$dr, Default, Default, Default, $gui)
	If @error = 1 Then
		Return
	EndIf
	$res = IniReadSection ( "profiles.ini", $newpname )
	If @error <> 1 Then
		While 1
			$newpname = InputBox( "Profile Name", $newpname & " already exists." & @CR & "Try something else.", Default, " M", Default, 150*$dr, Default, Default, Default, $gui)
			If @error = 1 Then
				Return
			EndIf
			$res = IniReadSection ( "profiles.ini", $newpname )
			If @error = 1 Then
				ExitLoop
			EndIf
		WEnd
	EndIf

	$filetext = FileRead( "profiles.ini" )	;get the text first
	$file = FileOpen( "profiles.ini", 2 )	;open and delete original
	$filetext = StringReplace ( $filetext, "[" & $pname & "]", "[" & $newpname & "]" )	;replace the profile
	FileWrite( $file, $filetext )	;write the text
	FileClose( $file)	;close the file
	_refreshpnames()
	ControlListView( $winname & " " & $winversion, "", $plistview, "Select", $index )
EndFunc
Func _ReadOptions($OptOpen=0)
	Local $i, $infoarr, $ans, $pfile
	If FileExists( "profiles.ini" ) Then
		$infoarr = IniReadSection( "profiles.ini", "Options" )
		For $i=0 To UBound($infoarr)-1
			If $infoarr[$i][0] = "AdvancedMode" Then
				If $infoarr[$i][1] = "True" Then
					$AdvancedMode = 1;
					If $OptOpen = 1 Then
						GUICtrlSetState( $ck_advonstart, $GUI_CHECKED)
					EndIf
				Else
					$AdvancedMode = 1;
				EndIf
			EndIf
			If $infoarr[$i][0] = "AutoRefresh" Then
				If $infoarr[$i][1] = "True" Then
					$autoref = 1
					If $OptOpen = 1 Then
						GUICtrlSetState( $ck_autorefresh, $GUI_CHECKED)
					EndIf
				Else
					$autoref  = 0
				EndIf
			EndIf
			If $infoarr[$i][0] = "AutoGateway" Then
				If $infoarr[$i][1] = "True" Then
					$autogw = 1
					If $OptOpen = 1 Then
						GUICtrlSetState( $ck_TypGateway, $GUI_CHECKED)
					EndIf
				Else
					$autogw  = 0
				EndIf
			EndIf
			If $infoarr[$i][0] = "AutoDNS" Then
				If $infoarr[$i][1] = "True" Then
					$autodns = 1
					If $OptOpen = 1 Then
						GUICtrlSetState( $ck_TypDNS, $GUI_CHECKED)
					EndIf
				Else
					$autodns  = 0
				EndIf
			EndIf
		Next
	EndIf
EndFunc

Func _SetOptions()
	Local $ans, $pfile

	If NOT FileExists( "profiles.ini" ) Then
		$ans = MsgBox( 4, "File not found", "Could not find config file." & @CR & "Create a new one?", Default, $gui)
		If $ans = 7 Then
			_ConfigFile()
			Return 1
		Else
			$pfile = FileOpen( "profiles.ini", 1 )
			FileWrite($pfile, "[Options]" & @CRLF )
			FileClose( $pfile )
		EndIf
	EndIf
	If GUICtrlRead($ck_advonstart)=$GUI_CHECKED Then
		IniWrite( "profiles.ini", "options", "AdvancedMode", "TRUE")
	Else
		IniWrite( "profiles.ini", "options", "AdvancedMode", "FALSE")
	EndIf
	If GUICtrlRead($ck_autorefresh)=$GUI_CHECKED Then
		IniWrite( "profiles.ini", "options", "AutoRefresh", "TRUE")
		$autoref = 1
	Else
		IniWrite( "profiles.ini", "options", "AutoRefresh", "FALSE")
		$autoref = 0
	EndIf
	If GUICtrlRead($ck_TypGateway)=$GUI_CHECKED Then
		IniWrite( "profiles.ini", "options", "AutoGateway", "TRUE")
		$autogw = 1
	Else
		IniWrite( "profiles.ini", "options", "AutoGateway", "FALSE")
		$autogw = 0
	EndIf
	If GUICtrlRead($ck_TypDNS)=$GUI_CHECKED Then
		IniWrite( "profiles.ini", "options", "AutoDNS", "TRUE")
		$autodns = 1
	Else
		IniWrite( "profiles.ini", "options", "AutoDNS", "FALSE")
		$autodns = 0
	EndIf
	_closerchild()
EndFunc

#EndRegion ;profiles

#Region - Error Functions
Func _wmierror($errorcode, $wmicode)
	If $wmicode = 84 Then
		MsgBox( 0, "Warning", "Error Code " & $errorcode & @CRLF & "IP is not enabled on the selected adapter." & @CR & "This could mean the adapter is not connected to any " & _
			"network or the DHCP server has not assigned a new IP yet.")
	ElseIf $errorcode = 99 Then
		MsgBox( 48, "Error", "Error Code 99" & @CR & "Error opening WMI COM object." & @CR & "The program is not able to function properly." _
			& @CR & @CR & "The problem will not close.")
	Else
		MsgBox(48, "Error", "There was a problem applying settings." & @CR & @CR & "Error Code " & $errorcode & "." & @CR & "WMI Error Code " & $wmicode & ".")
	EndIf
	GuiCtrlSetData( $statusset_lab, "Error setting IP")
EndFunc	; _wmierror

Func _ConfigFile($errorcode=0)
	Switch $errorcode
		Case 0
			_GUICtrlListView_DeleteAllItems(GUICtrlGetHandle($plistview))
			GuiCtrlSetData( $statusset_lab, "Configuration file not found")
			GUICtrlCreateListViewItem( "No config file found", $plistview )
		Case 51
			MsgBox( 48, "Error", "Error Code 51" & @CR & "There was a problem reading the profile names from the configuration file.")
		Case 52
			MsgBox( 48, "Error", "Error Code 52" & @CR & "There was a problem reading values from the configuration file.")
		Case 53
			GuiCtrlSetData( $statusset_lab, "Configuration file is corrupt")
		Case 54
			MsgBox( 48, "Error", "Error Code 54" & @CR & "Error writing to configuration file.")
		Case 55
			MsgBox( 48, "Error", "Error Code 55" & @CR & "Invalid internal data." & @CR & "Please report this immediately.")
		Case 56
			MsgBox( 48, "Error", "Error Code 56" & @CR & "Error writing to configuration file.")
		Case 57
			MsgBox( 48, "Error", "Error Code 57" & @CR & "Invalid internal data." & @CR & "Please report this immediately.")
		Case 58
			MsgBox( 48, "Error", "Error Code 58" & @CR & "Configuration file does not exist or is read-only.")
	EndSwitch
EndFunc

Func _AdapterModErrors($errorcode)
	Switch $errorcode
		Case 101
			GuiCtrlSetData( $statusset_lab, "Enable/Disable Error")
		Case 102
			GuiCtrlSetData( $statusset_lab, "Enable/Disable Error")
		Case 103
			GuiCtrlSetData( $statusset_lab, "Enable/Disable Error")
		Case 104
			GuiCtrlSetData( $statusset_lab, "Enable/Disable Error")
	EndSwitch
EndFunc

Func Error_Handle()
    Msgbox(0, "Debug Information", "An error has occured!" & @CRLF & @CRLF & _
             "err.description is: " & @TAB & $oErrors.description   & @CRLF & _
             "err.windescription:"  & @TAB & $oErrors.windescription & @CRLF & _
             "err.number is: "  & @TAB & Hex($oErrors.number,8) & @CRLF & _
             "err.lastdllerror is: " & @TAB & $oErrors.lastdllerror & @CRLF & _
             "err.scriptline is: "  & @TAB & $oErrors.scriptline    & @CRLF & _
             "err.source is: "  & @TAB & $oErrors.source    & @CRLF & _
             "err.helpfile is: "    & @TAB & $oErrors.helpfile  & @CRLF & _
             "err.helpcontext is: " & @TAB & $oErrors.helpcontext   & @CRLF & @CRLF & @CRLF)
    Return SetError($oErrors.number)

	; refer to "Com Errors.txt" for error descriptions
EndFunc
#EndRegion ;Error Functions
